var expect = require("chai").expect,
    tz     = require("./");

describe("tz-lookup", function() {
  function test(lat, lon, tzid) {
    it("should return \"" + tzid + "\" given " + lat + ", " + lon, function() {
      expect(tz(lat, lon)).to.equal(tzid);
    });
  }

  function fuzz(lat, lon, tzid) {
    it("should return \"" + tzid + "\" (or something more specific) given " + lat + ", " + lon, function() {
      var timezone = tz(lat, lon);

      if(tzid.slice(0, 3) !== "Etc" || timezone.slice(0, 3) === "Etc")
        expect(timezone).to.equal(tzid);
    });
  }

  function errorTest(lat, lon) {
    it("should throw an error given " + lat + ", " + lon, function() {
      try {
        tz(lat, lon)
      } catch (ex) {
        expect(ex.message).to.equal("invalid coordinates");
        return;
      }
      throw "Should not get here."
    });
  }

  /* These tests are hand-crafted. */
  test( 40.7092,  -74.0151,             "America/New_York");
  test( 42.3668,  -71.0546,             "America/New_York");
  test( 41.8976,  -87.6205,              "America/Chicago");
  test( 47.6897, -122.4023,          "America/Los_Angeles");
  test( 42.7235,  -73.6931,             "America/New_York");
  test( 42.5807,  -83.0223,              "America/Detroit");
  test( 36.8381,  -84.8500,  "America/Kentucky/Monticello");
  test( 40.1674,  -85.3583, "America/Indiana/Indianapolis");
  test( 37.9643,  -86.7453,    "America/Indiana/Tell_City");
  test( 38.6043,  -90.2417,              "America/Chicago");
  test( 41.1591, -104.8261,               "America/Denver");
  test( 35.1991, -111.6348,              "America/Phoenix");
  test( 43.1432, -115.6750,                "America/Boise");
  test( 47.5886, -122.3382,          "America/Los_Angeles");
  test( 58.3168, -134.4397,               "America/Juneau");
  test( 21.4381, -158.0493,             "Pacific/Honolulu");
  test( 42.7000,  -80.0000,              "America/Toronto");
  test( 51.0036, -114.0161,             "America/Edmonton");
  test(-16.4965,  -68.1702,               "America/La_Paz");
  test(-31.9369,  115.8453,              "Australia/Perth");
  test( 42.0000,  -87.5000,              "America/Chicago");

  /* Can handle string input as well as numerical input */
  test( "42.3668",  "-71.0546",         "America/New_York");
  test( "21.4381", "-158.0493",         "Pacific/Honolulu");

  /* These tests handle bad input. */
  errorTest( 100, 10 );
  errorTest( 10, 190 );
  errorTest( "hello", 10 );
  errorTest( 10, "hello" );
  errorTest( undefined, undefined );
  errorTest( {lat: 10, lon: 10}, null );

  /* These are automatically-generated fuzz-tests from v1. */
  fuzz( 74.1570,  171.0540, "Etc/GMT-11");
  fuzz( 36.3416, -175.9680, "Etc/GMT+12");
  fuzz(-76.7597,   23.0093, "Etc/GMT-2");
  fuzz( 65.2171,  -39.1875, "Etc/GMT+3");
  fuzz( 37.8358,  -89.0556, "America/Chicago");
  fuzz(  6.5049,  132.8593, "Etc/GMT-9");
  fuzz(-33.8291, -126.4846, "Etc/GMT+8");
  fuzz( -2.2708,   86.1435, "Etc/GMT-6");
  fuzz( 86.5338,  -42.8766, "Etc/GMT+3");
  fuzz(-35.6196,  152.2317, "Etc/GMT-10");
  fuzz(-59.0195, -121.6858, "Etc/GMT+8");
  fuzz(-29.3372,  -56.9745, "America/Argentina/Cordoba");
  fuzz( 82.3141,  -39.1331, "America/Godthab");
  fuzz(-21.9487,  163.8989, "Etc/GMT-11");
  fuzz(-24.5366, -115.1085, "Etc/GMT+8");
  fuzz(-50.8611,  -67.6471, "Etc/GMT+5");
  fuzz(  3.4135,   71.8540, "Etc/GMT-5");
  fuzz( 35.3462,   -2.0428, "Etc/GMT");
  fuzz( 54.1241,   95.1606, "Asia/Krasnoyarsk");
  fuzz(  6.9570,  -78.8378, "Etc/GMT+5");
  fuzz(-80.4809,  -74.3079, "Etc/GMT+5");
  fuzz( 37.6926,  153.9764, "Etc/GMT-10");
  fuzz(-45.2262, -154.6239, "Etc/GMT+10");
  fuzz( 61.1369,  -25.1156, "Etc/GMT+2");
  fuzz( 35.8970,  105.0863, "Asia/Chongqing");
  fuzz(-84.2731,   90.5347, "Etc/GMT-6");
  fuzz(-57.6384, -104.8362, "Etc/GMT+7");
  fuzz( 77.6074,   87.3492, "Etc/GMT-6");
  fuzz(-86.2052,  174.8244, "Etc/GMT-12");
  fuzz(-70.1543,  -86.0921, "Etc/GMT+6");
  fuzz( 38.2739, -123.5385, "Etc/GMT+8");
  fuzz( 74.6556,   17.2644, "Etc/GMT-1");
  fuzz( -3.6445,   24.5964, "Africa/Lubumbashi");
  fuzz( 21.9200,   76.3888, "Asia/Kolkata");
  fuzz( 81.0433,  -78.2488, "America/Iqaluit");
  fuzz( 76.2269,  135.0390, "Etc/GMT-9");
  fuzz(-25.3943,  173.9764, "Etc/GMT-12");
  fuzz( 78.5923,  140.9452, "Etc/GMT-9");
  fuzz(-88.5266,   49.3084, "Etc/GMT-3");
  fuzz(-53.9534, -129.8685, "Etc/GMT+9");
  fuzz(-57.4418,   70.4723, "Etc/GMT-5");
  fuzz(-70.4054,   88.0473, "Etc/GMT-6");
  fuzz(  4.9429,  125.6684, "Etc/GMT-8");
  fuzz( 41.4793,   -2.7493, "Europe/Madrid");
  fuzz(-12.6669,   56.2598, "Etc/GMT-4");
  fuzz( 60.7250, -126.4046, "America/Whitehorse");
  fuzz( 27.9550, -119.2723, "Etc/GMT+8");
  fuzz(-55.1090,  -25.8169, "Etc/GMT+2");
  fuzz(-63.4157,  161.6944, "Etc/GMT-11");
  fuzz( 27.1595,  -20.4821, "Etc/GMT+1");
  fuzz( 11.9399,    2.3295, "Africa/Ouagadougou");
  fuzz(-61.7108,   97.3103, "Etc/GMT-6");
  fuzz(  8.8483,   65.6012, "Etc/GMT-4");
  fuzz( 82.4238, -153.8071, "Etc/GMT+10");
  fuzz( 16.5041,  103.0204, "Asia/Bangkok");
  fuzz( 14.8329, -138.9238, "Etc/GMT+9");
  fuzz(-25.1415,  -10.2559, "Etc/GMT+1");
  fuzz( 81.6672,   64.5991, "Etc/GMT-4");
  fuzz(-76.4906,   79.6078, "Etc/GMT-5");
  fuzz( 72.8356,   -6.8700, "Etc/GMT");
  fuzz(  1.9915,  -15.7714, "Etc/GMT+1");
  fuzz( 72.4750, -122.6775, "America/Yellowknife");
  fuzz(-80.0271,   97.5079, "Etc/GMT-7");
  fuzz(-78.4514,  -46.9126, "Etc/GMT+3");
  fuzz(  4.8627, -154.9894, "Etc/GMT+10");
  fuzz(-20.3063,  -36.6612, "Etc/GMT+2");
  fuzz( 64.9576,  144.3597, "Asia/Magadan");
  fuzz( 65.7747,   -4.2121, "Etc/GMT");
  fuzz(  4.4840, -163.9921, "Etc/GMT+11");
  fuzz( 82.9728,   -1.6901, "Etc/GMT");
  fuzz(-72.0376,   85.8574, "Etc/GMT-6");
  fuzz(-67.9902,   85.7020, "Etc/GMT-6");
  fuzz(  9.3271, -128.6898, "Etc/GMT+9");
  fuzz( 88.2995,  103.0078, "Etc/GMT-7");
  fuzz( 84.2291,   94.3143, "Etc/GMT-6");
  fuzz(-66.9471,   63.9549, "Etc/GMT-4");
  fuzz( 27.0518,  107.9761, "Asia/Chongqing");
  fuzz(-33.3861, -100.8942, "Etc/GMT+7");
  fuzz( 20.2716,   28.7996, "Africa/Khartoum");
  fuzz(-18.6123,  137.4460, "Australia/Darwin");
  fuzz( 57.0724,  104.8747, "Asia/Irkutsk");
  fuzz( 30.4075,  113.4049, "Asia/Shanghai");
  fuzz(-53.8292, -140.3125, "Etc/GMT+9");
  fuzz( 67.9909,  164.1215, "Asia/Anadyr");
  fuzz(  7.2369,  162.8976, "Etc/GMT-11");
  fuzz( 86.4356,   -7.7277, "Etc/GMT+1");
  fuzz(-69.7742,   98.2968, "Etc/GMT-7");
  fuzz(-81.1398, -100.9004, "Etc/GMT+7");
  fuzz(-66.2857, -158.7325, "Etc/GMT+11");
  fuzz( 77.6378, -117.8879, "Etc/GMT+8");
  fuzz( 30.7623,  -84.0980, "America/New_York");
  fuzz(-81.2185,   44.1502, "Etc/GMT-3");
  fuzz( 80.4489,  -99.0211, "Etc/GMT+7");
  fuzz(-35.2499,  106.7770, "Etc/GMT-7");
  fuzz(-27.7215,  155.3404, "Etc/GMT-10");
  fuzz(-13.1575, -157.7665, "Etc/GMT+11");
  fuzz(  5.5659,  -28.0091, "Etc/GMT+2");
  fuzz( 89.0215,  110.0730, "Etc/GMT-7");
  fuzz(-48.3466,  114.9363, "Etc/GMT-8");
  fuzz( 15.8368,  -17.0156, "Etc/GMT+1");
  fuzz(  1.9845,  100.4508, "Asia/Jakarta");
  fuzz(  8.1223,  -90.2728, "Etc/GMT+6");
  fuzz(-58.8423,  -56.6807, "Etc/GMT+4");
  fuzz(-63.6216,  -19.4460, "Etc/GMT+1");
  fuzz( 69.3563,  -39.2451, "America/Godthab");
  fuzz(-19.5808,    3.5552, "Etc/GMT");
  fuzz(-79.3043,   40.0930, "Etc/GMT-3");
  fuzz( 16.1784,  106.2894, "Asia/Vientiane");
  fuzz( -0.3317, -152.6356, "Etc/GMT+10");
  fuzz( 84.9549, -113.4098, "Etc/GMT+8");
  fuzz( 22.1635,  -84.3358, "America/Havana");
  fuzz(-43.1612,  -80.4872, "Etc/GMT+5");
  fuzz( -6.0676,  148.7402, "Etc/GMT-10");
  fuzz( 65.9140,  -70.5960, "America/Iqaluit");
  fuzz(-49.1463,   -2.9151, "Etc/GMT");
  fuzz(-47.1088,    9.6141, "Etc/GMT-1");
  fuzz( 82.5071,   -2.3855, "Etc/GMT");
  fuzz(-13.4519, -133.6416, "Etc/GMT+9");
  fuzz(-51.5320,  172.5579, "Etc/GMT-12");
  fuzz( 69.8885, -107.6005, "America/Cambridge_Bay");
  fuzz( 57.6372,  -32.6427, "Etc/GMT+2");
  fuzz( 82.2254, -177.5415, "Etc/GMT+12");
  fuzz( 76.4427, -106.3772, "Etc/GMT+7");
  fuzz( 52.0299,  175.3019, "Etc/GMT-12");
  fuzz( -3.8484,   61.2497, "Etc/GMT-4");
  fuzz( 11.3070, -141.2751, "Etc/GMT+9");
  fuzz( 74.5179, -114.8270, "Etc/GMT+8");
  fuzz(-88.0080,    0.2568, "Etc/GMT");
  fuzz( 39.2287,   32.3653, "Europe/Istanbul");
  fuzz(-38.0034, -162.7460, "Etc/GMT+11");
  fuzz( 65.9913,   43.2401, "Europe/Moscow");
  fuzz(-81.2278,   84.8423, "Etc/GMT-6");
  fuzz(-77.3309,    4.9714, "Etc/GMT");
  fuzz(-40.3323,  -92.7225, "Etc/GMT+6");
  fuzz(-71.4413,   53.9770, "Etc/GMT-4");
  fuzz(-81.5634, -176.7552, "Etc/GMT+12");
  fuzz(-31.3366,  -57.4872, "America/Montevideo");
  fuzz(-65.9989, -108.7203, "Etc/GMT+7");
  fuzz(-29.7380,    4.2692, "Etc/GMT");
  fuzz( 67.7696,  158.2245, "Asia/Magadan");
  fuzz(-13.0738, -174.7293, "Etc/GMT+12");
  fuzz( 83.3732,   -1.8287, "Etc/GMT");
  fuzz(-16.3976, -144.6824, "Etc/GMT+10");
  fuzz(-78.8881,  155.5862, "Etc/GMT-10");
  fuzz( 56.7940, -134.4390, "Etc/GMT+9");
  fuzz(-71.8503,  -86.6314, "Etc/GMT+6");
  fuzz( 18.7113,  173.7809, "Etc/GMT-12");
  fuzz(-30.2745,  127.9174, "Australia/Perth");
  fuzz( -9.6156,   34.1749, "Africa/Blantyre");
  fuzz(-88.9531, -138.8994, "Etc/GMT+9");
  fuzz( 64.4928, -101.4695, "America/Rankin_Inlet");
  fuzz(-13.6290,   59.2620, "Etc/GMT-4");
  fuzz( 65.8424,  -52.6658, "America/Godthab");
  fuzz(-51.9663,   87.9671, "Etc/GMT-6");
  fuzz(  6.8921,   83.8461, "Etc/GMT-6");
  fuzz(-73.8085, -177.5977, "Etc/GMT+12");
  fuzz( 14.5729, -115.0088, "Etc/GMT+8");
  fuzz( 38.8582,  -78.9750, "America/New_York");
  fuzz(-39.3399,   10.6452, "Etc/GMT-1");
  fuzz(-16.7013,  117.9878, "Etc/GMT-8");
  fuzz(-27.8742,  146.6473, "Australia/Brisbane");
  fuzz( 45.9379,   62.7043, "Asia/Qyzylorda");
  fuzz( 48.2383, -159.1924, "Etc/GMT+11");
  fuzz( 35.3628,  -60.7545, "Etc/GMT+4");
  fuzz( 59.8003,  -13.8458, "Etc/GMT+1");
  fuzz( 73.6374,  134.6288, "Etc/GMT-9");
  fuzz( 64.3534,   73.2775, "Asia/Yekaterinburg");
  fuzz(-12.3055, -146.8800, "Etc/GMT+10");
  fuzz(-60.1624,  106.6697, "Etc/GMT-7");
  fuzz(-20.2119,   10.0562, "Etc/GMT-1");
  fuzz(-64.1778,  145.8386, "Etc/GMT-10");
  fuzz( 15.1007, -159.4022, "Etc/GMT+11");
  fuzz( 29.9944,  -99.8165, "America/Chicago");
  fuzz( -8.2125,   89.5989, "Etc/GMT-6");
  fuzz( 29.1503,   23.8957, "Africa/Tripoli");
  fuzz( 54.5334,   92.8278, "Asia/Krasnoyarsk");
  fuzz( 86.6541,   82.8372, "Etc/GMT-6");
  fuzz(-45.9957,  -25.9533, "Etc/GMT+2");
  fuzz(-39.9171, -148.8372, "Etc/GMT+10");
  fuzz(-13.6129,  125.3901, "Etc/GMT-8");
  fuzz(-27.8954, -126.8580, "Etc/GMT+8");
  fuzz( 89.4163,    3.7988, "Etc/GMT");
  fuzz( 82.7445, -170.2694, "Etc/GMT+11");
  fuzz(-86.5501,  171.9342, "Etc/GMT-11");
  fuzz(-62.0750, -159.4421, "Etc/GMT+11");
  fuzz( 87.1261,   98.0827, "Etc/GMT-7");
  fuzz( 52.1224, -162.3992, "Etc/GMT+11");
  fuzz(-57.4654, -144.8221, "Etc/GMT+10");
  fuzz( 69.5362,   20.2982, "Etc/GMT-1");
  fuzz( 43.6327,  -10.6603, "Etc/GMT+1");
  fuzz(-67.8373,  143.8463, "Etc/GMT-10");
  fuzz( 64.9790,  -41.9666, "America/Godthab");
  fuzz(-56.5021,  102.1402, "Etc/GMT-7");
  fuzz( 59.3773,  175.4929, "Etc/GMT-12");
  fuzz(-42.5784, -150.5788, "Etc/GMT+10");
  fuzz( 27.3021,  169.0382, "Etc/GMT-11");
  fuzz(-17.2287,   33.9961, "Africa/Maputo");
  fuzz(-10.6583, -153.0405, "Etc/GMT+10");
  fuzz( 68.3552, -149.0941, "America/Anchorage");
  fuzz(-81.2129,  -70.0119, "Etc/GMT+5");
  fuzz( -6.0114,  170.2811, "Etc/GMT-11");
  fuzz( 34.0850,  -57.8134, "Etc/GMT+4");
  fuzz( 40.8713,   86.7712, "Asia/Urumqi");
  fuzz( 58.9104, -108.2242, "America/Regina");
  fuzz(-71.8162, -139.1676, "Etc/GMT+9");
  fuzz(  7.7575,  -26.1777, "Etc/GMT+2");
  fuzz(-62.3068,  -43.7960, "Etc/GMT+3");
  fuzz(-60.8906,  -80.1729, "Etc/GMT+5");
  fuzz(-81.9434,  148.7109, "Etc/GMT-10");
  fuzz( 49.6877, -130.0361, "Etc/GMT+9");
  fuzz(-19.5458, -174.5469, "Etc/GMT+12");
  fuzz( 63.9166,   56.0705, "Europe/Moscow");
  fuzz(-55.2495, -171.1726, "Etc/GMT+11");
  fuzz( 54.7639,   41.9429, "Europe/Moscow");
  fuzz(-17.0228, -164.8056, "Etc/GMT+11");
  fuzz( 46.4048, -139.8344, "Etc/GMT+9");
  fuzz(-67.0837,   87.6011, "Etc/GMT-6");
  fuzz(-49.9741,  -23.5196, "Etc/GMT+2");
  fuzz(-74.8532, -178.9206, "Etc/GMT+12");
  fuzz(-74.4876, -148.6521, "Etc/GMT+10");
  fuzz( 22.4928,   90.6222, "Etc/GMT-6");
  fuzz(-27.8884, -126.1386, "Etc/GMT+8");
  fuzz( 47.8301, -138.8469, "Etc/GMT+9");
  fuzz(-10.1766,   83.7100, "Etc/GMT-6");
  fuzz( 81.8413,  -73.2339, "America/Iqaluit");
  fuzz(-18.2133, -165.2913, "Etc/GMT+11");
  fuzz( 51.0044, -168.5150, "Etc/GMT+11");
  fuzz(-11.4386,  -93.9416, "Etc/GMT+6");
  fuzz( 21.5364,  -40.3214, "Etc/GMT+3");
  fuzz( -2.1921,   10.6367, "Africa/Libreville");
  fuzz(  9.5718,  -83.1948, "America/Costa_Rica");
  fuzz(  1.7651,   49.2230, "Etc/GMT-3");
  fuzz( 83.0340,   70.0193, "Etc/GMT-5");
  fuzz( 11.9618,  -71.7086, "America/Bogota");
  fuzz(  9.3237,  -99.9586, "Etc/GMT+7");
  fuzz(-51.7204,  144.8009, "Etc/GMT-10");
  fuzz(-70.4944,  133.5942, "Etc/GMT-9");
  fuzz( 81.9516,   -9.3576, "Etc/GMT+1");
  fuzz(  0.0683,  -42.2255, "Etc/GMT+3");
  fuzz(-18.7081, -168.5762, "Etc/GMT+11");
  fuzz(  3.5566,  147.8802, "Etc/GMT-10");
  fuzz( 80.8597,  -77.3047, "Etc/GMT+5");
  fuzz( 65.5352,   74.4143, "Asia/Yekaterinburg");
  fuzz( 73.3870,   74.9842, "Etc/GMT-5");
  fuzz(-43.3577, -102.7139, "Etc/GMT+7");
  fuzz( 50.5575,  -93.9996, "America/Winnipeg");
  fuzz( 84.9867,  -50.2065, "Etc/GMT+3");
  fuzz(-88.1843,   57.8031, "Etc/GMT-4");
  fuzz(-85.9571,  -46.2760, "Etc/GMT+3");
  fuzz(-59.7937,  120.6820, "Etc/GMT-8");
  fuzz(-37.4311,   18.9410, "Etc/GMT-1");
  fuzz(-74.8911,   42.0323, "Etc/GMT-3");
  fuzz( 51.6740,  157.0986, "Asia/Kamchatka");
  fuzz( 46.7376,  142.8907, "Asia/Sakhalin");
  fuzz(-54.2821,   72.0090, "Etc/GMT-5");
  fuzz( 73.7638, -138.8240, "Etc/GMT+9");
  fuzz( 37.5756,  120.5804, "Asia/Shanghai");
  fuzz( 32.7113,   74.3851, "Asia/Karachi");
  fuzz(-60.3936,  159.6675, "Etc/GMT-11");
  fuzz(-38.5593, -101.7175, "Etc/GMT+7");
  fuzz(-24.4658,  -55.8260, "America/Asuncion");
  fuzz( 24.1446,  113.9533, "Asia/Shanghai");
  fuzz( 46.8222, -114.0462, "America/Denver");
  fuzz( 36.8550,  -52.6908, "Etc/GMT+4");
  fuzz(-30.2402,   82.6941, "Etc/GMT-6");
  fuzz(-52.4180,  -54.6639, "Etc/GMT+4");
  fuzz(-22.4292,   -8.2419, "Etc/GMT+1");
  fuzz(-28.6234,  111.7379, "Etc/GMT-7");
  fuzz(-87.2810,   85.4339, "Etc/GMT-6");
  fuzz( 60.6475,   66.0918, "Asia/Yekaterinburg");
  fuzz(-17.2465,  -96.5257, "Etc/GMT+6");
  fuzz(-41.3641,   62.4643, "Etc/GMT-4");
  fuzz(-41.8625,  105.4641, "Etc/GMT-7");
  fuzz( 64.5038,  -75.8160, "America/Iqaluit");
  fuzz( 61.4801,   57.7244, "Asia/Yekaterinburg");
  fuzz( -1.2214,  100.3532, "Etc/GMT-7");
  fuzz(-75.3549,  119.8456, "Etc/GMT-8");
  fuzz( 24.6805, -149.5537, "Etc/GMT+10");
  fuzz( 42.4884,  -12.5813, "Etc/GMT+1");
  fuzz( 62.5267,   96.4454, "Asia/Krasnoyarsk");
  fuzz(-49.2185, -140.2856, "Etc/GMT+9");
  fuzz( 35.5328,   32.0748, "Etc/GMT-2");
  fuzz( -9.4502, -119.1367, "Etc/GMT+8");
  fuzz(-25.1877,  139.8115, "Australia/Brisbane");
  fuzz( 13.6274,   99.6599, "Asia/Bangkok");
  fuzz( 79.1923,   20.0049, "Etc/GMT-1");
  fuzz(-49.3563,  -37.2322, "Etc/GMT+2");
  fuzz( -9.6665,  -43.4782, "America/Bahia");
  fuzz( 17.5016,   -8.0710, "Africa/Nouakchott");
  fuzz( 31.6830,  166.4328, "Etc/GMT-11");
  fuzz(-64.2712, -124.9474, "Etc/GMT+8");
  fuzz(  0.8471,  -97.9148, "Etc/GMT+7");
  fuzz( 24.7831,  -41.8663, "Etc/GMT+3");
  fuzz(-88.6873,    5.8902, "Etc/GMT");
  fuzz(  0.6952,   55.8237, "Etc/GMT-4");
  fuzz(  3.4841, -144.8032, "Etc/GMT+10");
  fuzz( 63.4112,  161.4826, "Asia/Magadan");
  fuzz( 64.1965, -116.9276, "America/Yellowknife");
  fuzz( 74.0116,  -35.9084, "America/Godthab");
  fuzz( 28.1819,   47.1326, "Asia/Riyadh");
  fuzz(-76.3513, -103.8152, "Etc/GMT+7");
  fuzz(-85.2215,   21.1860, "Etc/GMT-1");
  fuzz( 75.2332, -160.3352, "Etc/GMT+11");
  fuzz( 38.3537, -169.4163, "Etc/GMT+11");
  fuzz( 41.7287,  135.7781, "Etc/GMT-9");
  fuzz(-69.8508,   53.5052, "Etc/GMT-4");
  fuzz(-70.2233,   56.4435, "Etc/GMT-4");
  fuzz(-50.9611,   35.8599, "Etc/GMT-2");
  fuzz( 31.9738,  -38.3273, "Etc/GMT+3");
  fuzz(-50.6075,   42.9745, "Etc/GMT-3");
  fuzz( 31.4429,  -22.6502, "Etc/GMT+2");
  fuzz(-25.8522,  139.7641, "Australia/Brisbane");
  fuzz( 53.7611, -146.7696, "Etc/GMT+10");
  fuzz(-83.8971, -109.7864, "Etc/GMT+7");
  fuzz(-71.4058,  170.5107, "Etc/GMT-11");
  fuzz(-84.2677,   21.7663, "Etc/GMT-1");
  fuzz(-73.1301,  152.0056, "Etc/GMT-10");
  fuzz( 89.4106,  -95.1691, "Etc/GMT+6");
  fuzz(-85.4755, -172.7769, "Etc/GMT+12");
  fuzz( 83.8635,   11.3269, "Etc/GMT-1");
  fuzz( 77.4044, -148.5200, "Etc/GMT+10");
  fuzz( 35.7802,  165.9060, "Etc/GMT-11");
  fuzz( 83.3232, -148.3063, "Etc/GMT+10");
  fuzz( 88.3829,  117.5080, "Etc/GMT-8");
  fuzz( 18.7708,  -80.1699, "Etc/GMT+5");
  fuzz( 55.1606,   80.3125, "Asia/Novosibirsk");
  fuzz( 58.5365,  -99.8847, "America/Winnipeg");
  fuzz( 12.0527,  -82.9698, "Etc/GMT+6");
  fuzz(-67.8483,   -5.5705, "Etc/GMT");
  fuzz(  9.9915,  -24.7578, "Etc/GMT+2");
  fuzz(-62.4598, -132.1608, "Etc/GMT+9");
  fuzz(-48.5466,   59.1880, "Etc/GMT-4");
  fuzz( 19.0721,   -0.7923, "Africa/Bamako");
  fuzz( 44.3833,  -16.1446, "Etc/GMT+1");
  fuzz( 51.7151,   84.7338, "Asia/Omsk");
  fuzz(-25.4613,   62.8885, "Etc/GMT-4");
  fuzz(-58.6114,   20.1701, "Etc/GMT-1");
  fuzz( 39.8809,  -30.7253, "Etc/GMT+2");
  fuzz( -6.3067,  108.5385, "Etc/GMT-7");
  fuzz( 82.0906, -140.7886, "Etc/GMT+9");
  fuzz(-21.8276, -108.7314, "Etc/GMT+7");
  fuzz( 79.0094,  106.1970, "Etc/GMT-7");
  fuzz( 23.2615,   76.4792, "Asia/Kolkata");
  fuzz(-72.6989,  -54.4464, "Etc/GMT+4");
  fuzz(  5.3619,  -49.2853, "Etc/GMT+3");
  fuzz( 46.9836,  160.9876, "Etc/GMT-11");
  fuzz(-48.7114, -148.6698, "Etc/GMT+10");
  fuzz( -1.9481,  -36.6369, "Etc/GMT+2");
  fuzz(  5.7740,   96.7561, "Etc/GMT-6");
  fuzz( 43.7930, -146.5275, "Etc/GMT+10");
  fuzz(-45.9917, -116.9316, "Etc/GMT+8");
  fuzz(-33.4570,  -48.7267, "Etc/GMT+3");
  fuzz( 46.7260,   79.0294, "Asia/Almaty");
  fuzz( 54.2007, -121.4509, "America/Vancouver");
  fuzz(-43.9869, -167.1896, "Etc/GMT+11");
  fuzz( 11.5748, -108.4082, "Etc/GMT+7");
  fuzz( 16.9673,  161.8093, "Etc/GMT-11");
  fuzz(-46.5644,    5.0878, "Etc/GMT");
  fuzz( 57.9166,   96.0225, "Asia/Krasnoyarsk");
  fuzz(-52.0089,  167.3132, "Etc/GMT-11");
  fuzz(-31.6623,  174.4837, "Etc/GMT-12");
  fuzz(-63.6444, -167.7322, "Etc/GMT+11");
  fuzz(-73.7926,  121.1126, "Etc/GMT-8");
  fuzz( 19.8781,    9.8020, "Africa/Niamey");
  fuzz( 78.6778,  136.7877, "Etc/GMT-9");
  fuzz( 65.0340, -155.4731, "America/Anchorage");
  fuzz( 21.2294,  102.3456, "Asia/Vientiane");
  fuzz(-72.0741,   93.7158, "Etc/GMT-6");
  fuzz(-33.5592,  -36.6418, "Etc/GMT+2");
  fuzz(-61.0903, -106.8162, "Etc/GMT+7");
  fuzz( 31.3878,   97.7606, "Asia/Urumqi");
  fuzz( 14.6321,   74.8661, "Asia/Kolkata");
  fuzz( 73.9279,   56.0125, "Europe/Moscow");
  fuzz( 71.9715,   50.5316, "Etc/GMT-3");
  fuzz( 14.2696,   86.7119, "Etc/GMT-6");
  fuzz( 61.0509,   79.4277, "Asia/Yekaterinburg");
  fuzz( -5.8263,  -38.5891, "America/Fortaleza");
  fuzz(-83.7434,  104.1076, "Etc/GMT-7");
  fuzz(-71.5161,   41.0541, "Etc/GMT-3");
  fuzz( 66.1051,  -44.2991, "America/Godthab");
  fuzz( 69.1047,   40.2131, "Etc/GMT-3");
  fuzz(-70.2558, -124.9825, "Etc/GMT+8");
  fuzz( 61.9720, -122.8406, "America/Yellowknife");
  fuzz( 49.5920,  176.6431, "Etc/GMT-12");
  fuzz( 50.7092,   98.1654, "Asia/Ulaanbaatar");
  fuzz( 65.5451,  -60.2609, "Etc/GMT+4");
  fuzz( 42.7892,  -80.2958, "America/Toronto");
  fuzz(-22.0721, -116.2813, "Etc/GMT+8");
  fuzz(-65.7472,  -13.7719, "Etc/GMT+1");
  fuzz(-83.3863,  -19.3222, "Etc/GMT+1");
  fuzz( 73.5906,  145.7746, "Etc/GMT-10");
  fuzz(-35.7512,  169.9876, "Etc/GMT-11");
  fuzz(  0.9311, -145.7666, "Etc/GMT+10");
  fuzz( -0.9322, -133.3482, "Etc/GMT+9");
  fuzz( 20.1117,   53.8416, "Asia/Riyadh");
  fuzz(-22.8557,  -93.0837, "Etc/GMT+6");
  fuzz( 15.2343, -174.6112, "Etc/GMT+12");
  fuzz( 11.6601, -100.1228, "Etc/GMT+7");
  fuzz(-20.6653,  -39.4808, "Etc/GMT+3");
  fuzz(-51.8293,    4.4265, "Etc/GMT");
  fuzz(-58.7594,  164.8482, "Etc/GMT-11");
  fuzz( 66.7761,  148.5291, "Asia/Magadan");
  fuzz( 82.6942, -178.8467, "Etc/GMT+12");
  fuzz( 29.1745,  162.7696, "Etc/GMT-11");
  fuzz(-39.2928,    5.1189, "Etc/GMT");
  fuzz(-60.2643,   47.9395, "Etc/GMT-3");
  fuzz(-78.9523,  -70.0678, "Etc/GMT+5");
  fuzz( 70.2053,  164.5446, "Etc/GMT-11");
  fuzz( -5.3391,   16.3601, "Africa/Kinshasa");
  fuzz( 46.0719,  -13.5487, "Etc/GMT+1");
  fuzz( 81.9632, -117.6559, "Etc/GMT+8");
  fuzz( 38.5756,   94.5492, "Asia/Urumqi");
  fuzz(-52.5582,    9.6789, "Etc/GMT-1");
  fuzz( 47.0239, -144.7794, "Etc/GMT+10");
  fuzz(-70.3520,  -93.0058, "Etc/GMT+6");
  fuzz(-47.1717, -127.4868, "Etc/GMT+8");
  fuzz(-76.8177,   61.6831, "Etc/GMT-4");
  fuzz( 48.0880,   48.7792, "Asia/Aqtau");
  fuzz(-78.7523,   10.6614, "Etc/GMT-1");
  fuzz(-75.8020,  -95.6451, "Etc/GMT+6");
  fuzz( 56.3665,   89.3418, "Asia/Krasnoyarsk");
  fuzz( 23.5878,  -27.3371, "Etc/GMT+2");
  fuzz( 27.3337,   40.2867, "Asia/Riyadh");
  fuzz( -2.9802,  -11.5258, "Etc/GMT+1");
  fuzz(-19.3295,  -72.3595, "Etc/GMT+5");
  fuzz( 19.2194,   19.0398, "Africa/Ndjamena");
  fuzz( 84.1433,  110.0979, "Etc/GMT-7");
  fuzz( 22.4242,  146.5106, "Etc/GMT-10");
  fuzz(  5.0789,   34.1745, "Africa/Juba");
  fuzz( -0.9584,  -49.4351, "America/Belem");
  fuzz( 57.1181,   69.5137, "Asia/Yekaterinburg");
  fuzz( 74.9076,  135.4116, "Etc/GMT-9");
  fuzz(-39.6476,  158.0487, "Etc/GMT-11");
  fuzz(-85.7699,  -32.1458, "Etc/GMT+2");
  fuzz(-28.4158,   60.0514, "Etc/GMT-4");
  fuzz(-87.6453,    5.4824, "Etc/GMT");
  fuzz( 80.8535,  114.0859, "Etc/GMT-8");
  fuzz(  9.0181,   27.4099, "Africa/Juba");
  fuzz(-67.7483,  -86.2001, "Etc/GMT+6");
  fuzz( 34.3893,   16.5065, "Etc/GMT-1");
  fuzz( 11.9072,   13.9995, "Africa/Lagos");
  fuzz( 14.7160,   51.3307, "Etc/GMT-3");
  fuzz( -0.7433,  146.9675, "Etc/GMT-10");
  fuzz(-37.4406,  -16.5397, "Etc/GMT+1");
  fuzz( 30.0807,  -93.3324, "America/Chicago");
  fuzz( 60.0376,  -36.9155, "Etc/GMT+2");
  fuzz(-73.7128,  -13.5670, "Etc/GMT+1");
  fuzz( 77.5332,    3.1532, "Etc/GMT");
  fuzz(-70.7016,  120.4294, "Etc/GMT-8");
  fuzz(-23.3847,  -56.5457, "America/Asuncion");
  fuzz(-78.0584,  -72.0259, "Etc/GMT+5");
  fuzz( 39.8811,   26.3869, "Europe/Istanbul");
  fuzz( 69.0819,   49.1753, "Europe/Moscow");
  fuzz(-36.3717,  -29.8321, "Etc/GMT+2");
  fuzz(-58.4294, -106.2015, "Etc/GMT+7");
  fuzz( 30.7028, -172.0602, "Etc/GMT+11");
  fuzz( 89.8886, -129.0336, "Etc/GMT+9");
  fuzz(-11.5868,   78.5775, "Etc/GMT-5");
  fuzz(-65.5541,  137.9976, "Etc/GMT-9");
  fuzz( 29.1968,   58.7977, "Asia/Tehran");
  fuzz(-57.2955,   84.2354, "Etc/GMT-6");
  fuzz( 11.9446,  -88.5161, "Etc/GMT+6");
  fuzz( 25.5442,  147.2616, "Etc/GMT-10");
  fuzz(-22.5594, -107.9871, "Etc/GMT+7");
  fuzz( 76.9016, -138.1010, "Etc/GMT+9");
  fuzz(-81.8396,  -24.4442, "Etc/GMT+2");
  fuzz(-52.4988,  -73.0546, "America/Santiago");
  fuzz(-29.1779, -178.4509, "Etc/GMT+12");
  fuzz(-32.6964,  164.4804, "Etc/GMT-11");
  fuzz( 37.1155, -178.7043, "Etc/GMT+12");
  fuzz( 26.3241,  -11.1860, "Africa/El_Aaiun");
  fuzz( 10.6372,  -93.9120, "Etc/GMT+6");
  fuzz(  5.2142,  -13.1270, "Etc/GMT+1");
  fuzz(-47.6187,   75.4544, "Etc/GMT-5");
  fuzz(-81.9763,  -68.2256, "Etc/GMT+5");
  fuzz(-52.2226,   11.1925, "Etc/GMT-1");
  fuzz(-36.1354,   37.2208, "Etc/GMT-2");
  fuzz(-72.4895,   30.3547, "Etc/GMT-2");
  fuzz(-79.7195,    9.2059, "Etc/GMT-1");
  fuzz(-11.9435,  161.1927, "Etc/GMT-11");
  fuzz(-30.8355,   -3.1936, "Etc/GMT");
  fuzz( 16.3487,  -59.5819, "Etc/GMT+4");
  fuzz( 10.9075,  113.8886, "Etc/GMT-8");
  fuzz(-80.6001,  -89.2199, "Etc/GMT+6");
  fuzz( 11.2986, -105.9926, "Etc/GMT+7");
  fuzz( 74.5094,  -46.1125, "America/Godthab");
  fuzz(-18.0039,  137.1668, "Australia/Darwin");
  fuzz( 24.9853,  143.6800, "Etc/GMT-10");
  fuzz( 12.5885, -149.7712, "Etc/GMT+10");
  fuzz( 20.6946, -166.7874, "Etc/GMT+11");
  fuzz( 18.0707,  111.0846, "Etc/GMT-7");
  fuzz(-12.1893,   97.5947, "Etc/GMT-7");
  fuzz(-53.1599,  -79.9267, "Etc/GMT+5");
  fuzz( 61.3497,  -16.5805, "Etc/GMT+1");
  fuzz( -0.3483,  176.0804, "Etc/GMT-12");
  fuzz( 45.9164, -129.8466, "Etc/GMT+9");
  fuzz( 78.7482, -111.5438, "Etc/GMT+7");
  fuzz( 16.7404, -168.6961, "Etc/GMT+11");
  fuzz(  3.1497,  -63.0510, "America/Boa_Vista");
  fuzz( -7.0628,   94.3797, "Etc/GMT-6");
  fuzz( 33.0975,   21.8914, "Etc/GMT-1");
  fuzz( 36.0659,   98.8804, "Asia/Urumqi");
  fuzz(-64.8447,  -33.6808, "Etc/GMT+2");
  fuzz( 48.6762,   79.7838, "Asia/Almaty");
  fuzz(-18.1228, -108.7803, "Etc/GMT+7");
  fuzz(  5.6914, -155.6193, "Etc/GMT+10");
  fuzz(-11.9945,  -88.5650, "Etc/GMT+6");
  fuzz(-69.6870,    4.3549, "Etc/GMT");
  fuzz(-45.0974,  120.9930, "Etc/GMT-8");
  fuzz( 39.1590,  -44.7148, "Etc/GMT+3");
  fuzz( 59.6321,   35.7763, "Europe/Moscow");
  fuzz( 31.9457,  -89.0334, "America/Chicago");
  fuzz(-58.8632, -145.8610, "Etc/GMT+10");
  fuzz(-88.5326,  -77.1353, "Etc/GMT+5");
  fuzz(-72.7168,  153.3615, "Etc/GMT-10");
  fuzz(-44.8775,  151.4961, "Etc/GMT-10");
  fuzz( 45.4515,  -66.2694, "America/Moncton");
  fuzz( 50.1317, -162.5615, "Etc/GMT+11");
  fuzz( 23.9133,  -47.3344, "Etc/GMT+3");
  fuzz( 45.3159,   74.4388, "Asia/Almaty");
  fuzz(-32.2242, -152.3427, "Etc/GMT+10");
  fuzz(-84.5991,  178.0880, "Etc/GMT-12");
  fuzz( 55.6554,  -36.1852, "Etc/GMT+2");
  fuzz(  8.2690, -139.8680, "Etc/GMT+9");
  fuzz(-64.0375, -175.6464, "Etc/GMT+12");
  fuzz(-38.7002,   30.9041, "Etc/GMT-2");
  fuzz( 32.6406, -148.2346, "Etc/GMT+10");
  fuzz(-89.0031,  -51.0590, "Etc/GMT+3");
  fuzz(-75.5718,  -33.5581, "Etc/GMT+2");
  fuzz(-34.3706,   -1.3190, "Etc/GMT");
  fuzz( 22.9471,   71.5664, "Asia/Kolkata");
  fuzz( 39.4891,   29.9276, "Europe/Istanbul");
  fuzz(-19.2516, -113.1230, "Etc/GMT+8");
  fuzz(-60.1234,   63.6826, "Etc/GMT-4");
  fuzz(-67.4342,  164.0926, "Etc/GMT-11");
  fuzz( 69.5459,  -40.9566, "America/Godthab");
  fuzz( 11.4472,   89.0513, "Etc/GMT-6");
  fuzz( 30.1239,  -71.7722, "Etc/GMT+5");
  fuzz( 33.5446,  -15.4414, "Etc/GMT+1");
  fuzz(-64.6563,  124.3883, "Etc/GMT-8");
  fuzz(-73.8942,   93.0565, "Etc/GMT-6");
  fuzz( 43.1110,  172.7416, "Etc/GMT-12");
  fuzz( 15.5587,   -6.0105, "Africa/Nouakchott");
  fuzz( -8.2920,  -88.6828, "Etc/GMT+6");
  fuzz(-59.2557,    2.1395, "Etc/GMT");
  fuzz( 88.7863,  160.8455, "Etc/GMT-11");
  fuzz( -1.7834, -156.6977, "Etc/GMT+10");
  fuzz(-71.6264,  166.6398, "Etc/GMT-11");
  fuzz(-20.7129,   -5.4805, "Etc/GMT");
  fuzz(-74.1031, -147.1960, "Etc/GMT+10");
  fuzz( -9.2480,  162.6285, "Etc/GMT-11");
  fuzz( 78.7594,  111.3550, "Etc/GMT-7");
  fuzz(-25.1121,  -56.3599, "America/Asuncion");
  fuzz(-78.1030, -175.0678, "Etc/GMT+12");
  fuzz(-19.7405,    7.2852, "Etc/GMT");
  fuzz( 73.3277, -129.7752, "Etc/GMT+9");
  fuzz(-81.1091,   67.9301, "Etc/GMT-5");
  fuzz( 58.6718,   71.7465, "Asia/Yekaterinburg");
  fuzz(-50.9393,  -81.3847, "Etc/GMT+5");
  fuzz(-15.0811,   62.1845, "Etc/GMT-4");
  fuzz( 38.7813, -105.5734, "America/Denver");
  fuzz(-38.3397,   -2.5827, "Etc/GMT");
  fuzz(-29.9893,   31.7480, "Etc/GMT-2");
  fuzz(-65.7868, -144.0373, "Etc/GMT+10");
  fuzz(-63.5631,  -96.1916, "Etc/GMT+6");
  fuzz(-49.8275, -137.8153, "Etc/GMT+9");
  fuzz(-22.1685, -106.4918, "Etc/GMT+7");
  fuzz( 53.4450,   25.5964, "Europe/Minsk");
  fuzz( -7.5048,  -26.1590, "Etc/GMT+2");
  fuzz(-13.2258, -131.5905, "Etc/GMT+9");
  fuzz(-24.2303,  -35.2264, "Etc/GMT+2");
  fuzz(-51.3001,  -72.2580, "America/Argentina/Rio_Gallegos");
  fuzz(-87.5627,  -74.4104, "Etc/GMT+5");
  fuzz(-87.9652,   97.6447, "Etc/GMT-7");
  fuzz(-57.0310,  175.3371, "Etc/GMT-12");
  fuzz(-36.8179,  154.1523, "Etc/GMT-10");
  fuzz( 23.8272, -115.9005, "Etc/GMT+8");
  fuzz( 85.6758,  133.4539, "Etc/GMT-9");
  fuzz( 83.2706,  -97.2362, "Etc/GMT+6");
  fuzz(-84.7923, -100.8770, "Etc/GMT+7");
  fuzz( 80.9315,    0.8029, "Etc/GMT");
  fuzz( 64.6617,  160.8968, "Asia/Magadan");
  fuzz( 50.9116,  160.4791, "Etc/GMT-11");
  fuzz(-53.0361, -175.0102, "Etc/GMT+12");
  fuzz( 53.5006,  178.9430, "Etc/GMT-12");
  fuzz(-80.3814,  -85.7017, "Etc/GMT+6");
  fuzz( 33.5941,  164.3622, "Etc/GMT-11");
  fuzz(-21.1616, -153.6055, "Etc/GMT+10");
  fuzz( -7.9605,    5.2113, "Etc/GMT");
  fuzz( 89.6820,   84.4382, "Etc/GMT-6");
  fuzz( 61.6405,   69.4836, "Asia/Yekaterinburg");
  fuzz(-44.6428,   65.0786, "Etc/GMT-4");
  fuzz(-12.9104,   36.1809, "Africa/Maputo");
  fuzz( 52.5127,  -65.5284, "America/Goose_Bay");
  fuzz( -2.1186,   11.7021, "Africa/Libreville");
  fuzz(-49.3764,   82.1674, "Etc/GMT-5");
  fuzz(-35.8670,    7.1723, "Etc/GMT");
  fuzz( 71.1447,  -61.8739, "Etc/GMT+4");
  fuzz( 41.9794,  -93.6538, "America/Chicago");
  fuzz( -8.4162,  -10.3411, "Etc/GMT+1");
  fuzz( 82.8749,  103.0723, "Etc/GMT-7");
  fuzz(-51.8949,  -99.2419, "Etc/GMT+7");
  fuzz( 46.7966,  -54.2088, "Etc/GMT+4");
  fuzz( 59.3750,   40.2467, "Europe/Moscow");
  fuzz(-32.7642,  171.7136, "Etc/GMT-11");
  fuzz( -6.9124,   59.7324, "Etc/GMT-4");
  fuzz(-81.9828, -126.6785, "Etc/GMT+8");
  fuzz( 77.4382,  112.6295, "Etc/GMT-8");
  fuzz(  0.6745,  128.7060, "Etc/GMT-9");
  fuzz( -6.1405,   27.0324, "Africa/Lubumbashi");
  fuzz( 78.1733,  -60.1611, "America/Godthab");
  fuzz( 78.7287,   31.6391, "Etc/GMT-2");
  fuzz( 76.8343,   72.9464, "Etc/GMT-5");
  fuzz(-30.6183, -130.6706, "Etc/GMT+9");
  fuzz(-50.5210, -135.5650, "Etc/GMT+9");
  fuzz( 81.6766, -150.5689, "Etc/GMT+10");
  fuzz(-73.8165,  -98.1275, "Etc/GMT+7");
  fuzz( 58.7276, -159.4542, "Etc/GMT+11");
  fuzz( 28.0069,   27.9217, "Africa/Cairo");
  fuzz(-86.2406,  -28.1941, "Etc/GMT+2");
  fuzz(  8.5804,   51.2834, "Etc/GMT-3");
  fuzz(-74.4693,   60.1914, "Etc/GMT-4");
  fuzz(-61.5757,  115.0670, "Etc/GMT-8");
  fuzz(-24.0170,  108.2608, "Etc/GMT-7");
  fuzz(-39.2819,  161.8476, "Etc/GMT-11");
  fuzz( 17.5589,   82.9606, "Asia/Kolkata");
  fuzz( 87.8138,    5.5738, "Etc/GMT");
  fuzz( 77.1166,   65.9438, "Etc/GMT-4");
  fuzz( 77.0070,  -58.1725, "America/Godthab");
  fuzz( 22.7183,  136.8610, "Etc/GMT-9");
  fuzz( 78.5149, -103.5002, "Etc/GMT+7");
  fuzz(-54.3852,  -24.6720, "Etc/GMT+2");
  fuzz(-23.8494,  -20.0771, "Etc/GMT+1");
  fuzz( 34.0027, -155.6928, "Etc/GMT+10");
  fuzz(-11.7035,   78.7516, "Etc/GMT-5");
  fuzz(-61.9594,   16.3808, "Etc/GMT-1");
  fuzz(-81.8691,  -66.1395, "Etc/GMT+4");
  fuzz( 25.1439,   50.4092, "Asia/Riyadh");
  fuzz( 55.8404, -139.0395, "Etc/GMT+9");
  fuzz( 13.5243,   26.5038, "Africa/Khartoum");
  fuzz(-47.5659,  -64.1265, "Etc/GMT+4");
  fuzz(-19.5728,  134.1770, "Australia/Darwin");
  fuzz( 37.7332, -116.5272, "America/Los_Angeles");
  fuzz(-30.6651,  120.3113, "Australia/Perth");
  fuzz(-64.5226, -131.2262, "Etc/GMT+9");
  fuzz( 74.6277,  -33.1710, "America/Godthab");
  fuzz( 53.6035,  -97.5722, "America/Winnipeg");
  fuzz(-47.7062,  -57.5437, "Etc/GMT+4");
  fuzz( 19.4978, -152.6365, "Etc/GMT+10");
  fuzz(-52.1613,  120.2794, "Etc/GMT-8");
  fuzz(-42.5258, -118.5908, "Etc/GMT+8");
  fuzz(-51.7195,  -99.9791, "Etc/GMT+7");
  fuzz(-35.1722,   40.2418, "Etc/GMT-3");
  fuzz( 55.5158,   58.6481, "Asia/Yekaterinburg");
  fuzz(  9.1997,   92.0876, "Etc/GMT-6");
  fuzz(-66.3388,  126.8807, "Etc/GMT-8");
  fuzz(-29.9971,  -36.3532, "Etc/GMT+2");
  fuzz(-45.3014,   46.4203, "Etc/GMT-3");
  fuzz( 75.0630,   -8.6723, "Etc/GMT+1");
  fuzz(-34.6250,  138.1973, "Etc/GMT-9");
  fuzz( 35.2991,  160.5375, "Etc/GMT-11");
  fuzz( 26.6799,  -75.7073, "Etc/GMT+5");
  fuzz(-21.7799,  -39.3603, "Etc/GMT+3");
  fuzz(  2.5932, -127.2959, "Etc/GMT+8");
  fuzz( 50.1649,  -30.9249, "Etc/GMT+2");
  fuzz(-10.3277,   38.6084, "Africa/Dar_es_Salaam");
  fuzz( 34.7560,   44.4394, "Asia/Baghdad");
  fuzz(-58.5146, -107.3772, "Etc/GMT+7");
  fuzz(-34.0346,  -18.9657, "Etc/GMT+1");
  fuzz(-77.4349,  -27.7859, "Etc/GMT+2");
  fuzz(-44.7846,   18.7312, "Etc/GMT-1");
  fuzz( 62.6169,  103.2882, "Asia/Krasnoyarsk");
  fuzz(  6.1188,  -91.0388, "Etc/GMT+6");
  fuzz(-42.0855, -151.4356, "Etc/GMT+10");
  fuzz( 10.3662,  -98.3069, "Etc/GMT+7");
  fuzz(-43.3414,    2.8937, "Etc/GMT");
  fuzz( -2.6981,  -73.2412, "America/Lima");
  fuzz( -4.9274,  -65.3226, "America/Manaus");
  fuzz( 45.4233,  159.7870, "Etc/GMT-11");
  fuzz(-70.4777,   77.0827, "Etc/GMT-5");
  fuzz( 71.1648, -117.7618, "America/Yellowknife");
  fuzz( 20.3189, -110.1766, "Etc/GMT+7");
  fuzz( 54.7482,    5.0993, "Etc/GMT");
  fuzz( 18.2024,  177.1882, "Etc/GMT-12");
  fuzz(-69.4669,  -30.6038, "Etc/GMT+2");
  fuzz( 39.9430,   95.8967, "Asia/Urumqi");
  fuzz(-43.9501,  116.8410, "Etc/GMT-8");
  fuzz(-52.9067,   95.3211, "Etc/GMT-6");
  fuzz(-68.6827, -168.3637, "Etc/GMT+11");
  fuzz( 36.4006, -168.9528, "Etc/GMT+11");
  fuzz(-17.1282,   98.3376, "Etc/GMT-7");
  fuzz( 13.0509,  112.9887, "Etc/GMT-8");
  fuzz(-77.6289, -175.3517, "Etc/GMT+12");
  fuzz(-81.7019,   17.0685, "Etc/GMT-1");
  fuzz( 16.4146,  -48.8733, "Etc/GMT+3");
  fuzz( 44.2906,  -44.2785, "Etc/GMT+3");
  fuzz(  1.1807,  155.0310, "Etc/GMT-10");
  fuzz( 58.5594,   34.6095, "Europe/Moscow");
  fuzz( 67.6703,    3.7712, "Etc/GMT");
  fuzz(-55.8896, -130.9671, "Etc/GMT+9");
  fuzz(  7.6068, -135.3270, "Etc/GMT+9");
  fuzz( 55.3226,  -10.6266, "Etc/GMT+1");
  fuzz(-52.7951,  -13.2192, "Etc/GMT+1");
  fuzz( 55.2956,   32.0908, "Europe/Moscow");
  fuzz(-76.9132,   -0.3444, "Etc/GMT");
  fuzz(-50.5695, -141.3061, "Etc/GMT+9");
  fuzz( 86.6619,  175.9517, "Etc/GMT-12");
  fuzz(-43.2216,   50.1909, "Etc/GMT-3");
  fuzz(-15.3693,   36.5350, "Africa/Maputo");
  fuzz(-19.4016,   47.3511, "Indian/Antananarivo");
  fuzz( 23.3162,   12.8176, "Africa/Niamey");
  fuzz(-57.8650,   85.1383, "Etc/GMT-6");
  fuzz(-62.3094,  -86.5976, "Etc/GMT+6");
  fuzz(-87.6082, -133.6137, "Etc/GMT+9");
  fuzz( 75.0037, -109.9942, "America/Yellowknife");
  fuzz(-29.9925,  162.0515, "Etc/GMT-11");
  fuzz(-71.0739,  177.0212, "Etc/GMT-12");
  fuzz(-70.0133,  138.5791, "Etc/GMT-9");
  fuzz(-50.5134, -132.2434, "Etc/GMT+9");
  fuzz(-69.2856, -158.3472, "Etc/GMT+11");
  fuzz( 41.4247,  121.1758, "Asia/Shanghai");
  fuzz( 49.0067,   17.4505, "Europe/Prague");
  fuzz(  5.5599,  -36.2498, "Etc/GMT+2");
  fuzz(-53.1290,  -34.1179, "Etc/GMT+2");
  fuzz(-45.3015,   95.6032, "Etc/GMT-6");
  fuzz( 35.4434,   30.1379, "Etc/GMT-2");
  fuzz( 19.0771,  117.6963, "Etc/GMT-8");
  fuzz(-57.4456,  117.2738, "Etc/GMT-8");
  fuzz(-55.8112,   50.9322, "Etc/GMT-3");
  fuzz(-22.7467,  130.6468, "Australia/Darwin");
  fuzz( 47.6746, -173.9579, "Etc/GMT+12");
  fuzz(-83.0850,   37.1593, "Etc/GMT-2");
  fuzz(-89.4729, -107.6112, "Etc/GMT+7");
  fuzz(-75.3231,  166.6594, "Etc/GMT-11");
  fuzz( 56.9615, -137.4632, "Etc/GMT+9");
  fuzz(-86.0698,  -59.4156, "Etc/GMT+4");
  fuzz(-21.9188, -163.8836, "Etc/GMT+11");
  fuzz(-55.8930,   18.4044, "Etc/GMT-1");
  fuzz( -9.8513,  -93.6979, "Etc/GMT+6");
  fuzz(-42.8422,  167.9747, "Etc/GMT-11");
  fuzz(-81.0107,   82.0871, "Etc/GMT-5");
  fuzz(-82.3512,  -44.9035, "Etc/GMT+3");
  fuzz(-89.9834,  105.3329, "Etc/GMT-7");
  fuzz(-69.3843,   66.5420, "Etc/GMT-4");
  fuzz(-87.0517,   95.0439, "Etc/GMT-6");
  fuzz( 76.5862,   69.8372, "Etc/GMT-5");
  fuzz(-88.2382,   44.0106, "Etc/GMT-3");
  fuzz( 63.8349,  152.5360, "Asia/Magadan");
  fuzz( 28.9144,  134.5977, "Etc/GMT-9");
  fuzz(-43.6364, -178.5022, "Etc/GMT+12");
  fuzz( -2.2519,  -39.0103, "Etc/GMT+3");
  fuzz(-40.5984,  139.3950, "Etc/GMT-9");
  fuzz(-79.2276,  161.0423, "Etc/GMT-11");
  fuzz(-20.7583,  120.7570, "Australia/Perth");
  fuzz( 79.9967,   51.9623, "Etc/GMT-3");
  fuzz( 36.4171,   87.8762, "Asia/Urumqi");
  fuzz( 30.0397,  177.6772, "Etc/GMT-12");
  fuzz( 18.9943, -152.4780, "Etc/GMT+10");
  fuzz(-14.0596,   86.3116, "Etc/GMT-6");
  fuzz( 72.7945, -139.8945, "Etc/GMT+9");
  fuzz( 62.7709, -118.4994, "America/Yellowknife");
  fuzz( 73.0256,  168.5741, "Etc/GMT-11");
  fuzz(-39.0968,   68.9522, "Etc/GMT-5");
  fuzz( 21.2630,   17.5662, "Africa/Ndjamena");
  fuzz( 63.7417, -115.2235, "America/Yellowknife");
  fuzz(-88.6690, -137.9408, "Etc/GMT+9");
  fuzz( 44.0343,  123.8136, "Asia/Harbin");
  fuzz( 16.3843, -108.0407, "Etc/GMT+7");
  fuzz( 81.6018,  -59.8101, "America/Godthab");
  fuzz(-53.7261, -103.7358, "Etc/GMT+7");
  fuzz(-11.7668,  -21.5652, "Etc/GMT+1");
  fuzz( 39.4444,  -34.7815, "Etc/GMT+2");
  fuzz(-19.7693,  -96.4207, "Etc/GMT+6");
  fuzz(-13.8576,   51.6961, "Etc/GMT-3");
  fuzz( 18.8445, -131.1139, "Etc/GMT+9");
  fuzz(-31.1031, -153.9108, "Etc/GMT+10");
  fuzz(-87.9548,  -67.9416, "Etc/GMT+5");
  fuzz( 51.5641,  -63.8453, "America/Montreal");
  fuzz(-38.1635,  -57.7626, "America/Argentina/Buenos_Aires");
  fuzz( 11.7639,  -39.5294, "Etc/GMT+3");
  fuzz(-44.1958,   -9.0258, "Etc/GMT+1");
  fuzz( 36.1970, -107.8392, "America/Denver");
  fuzz(-58.6968, -112.5002, "Etc/GMT+8");
  fuzz(-43.6842,  144.5683, "Etc/GMT-10");
  fuzz(-48.6603,  144.6739, "Etc/GMT-10");
  fuzz(-86.3804,   -6.9377, "Etc/GMT");
  fuzz( 26.0985, -105.9614, "America/Monterrey");
  fuzz( 32.3567,  113.1371, "Asia/Shanghai");
  fuzz( 58.7086, -178.1062, "Etc/GMT+12");
  fuzz( 27.4785,   48.7596, "Asia/Riyadh");
  fuzz( 85.7064,   95.1236, "Etc/GMT-6");
  fuzz( 12.2648,  -58.6632, "Etc/GMT+4");
  fuzz( 41.5358,   69.8340, "Asia/Tashkent");
  fuzz(-22.3631,  -25.7685, "Etc/GMT+2");
  fuzz( 16.6584, -163.3459, "Etc/GMT+11");
  fuzz(-40.0583,    7.9073, "Etc/GMT-1");
  fuzz(-31.7125,  -60.6771, "America/Argentina/Cordoba");
  fuzz( 45.0453,  -80.8260, "Etc/GMT+5");
  fuzz( 55.3174, -111.7919, "America/Edmonton");
  fuzz(-62.5699,  -91.5991, "Etc/GMT+6");
  fuzz( 85.0999,  174.6778, "Etc/GMT-12");
  fuzz(  4.7878,  -33.8670, "Etc/GMT+2");
  fuzz(-74.0289,  116.7745, "Etc/GMT-8");
  fuzz( 74.5144,   66.3875, "Etc/GMT-4");
  fuzz(-51.6008,  -15.8030, "Etc/GMT+1");
  fuzz(-86.0107,   84.9995, "Etc/GMT-6");
  fuzz(-26.7396, -100.4335, "Etc/GMT+7");
  fuzz(-84.5774,   15.5615, "Etc/GMT-1");
  fuzz(-44.4748,   51.6902, "Etc/GMT-3");
  fuzz(-70.6811,  160.8882, "Etc/GMT-11");
  fuzz(-42.2734,  -96.4139, "Etc/GMT+6");
  fuzz(-39.7731,   31.7892, "Etc/GMT-2");
  fuzz( 23.4918,   -4.6733, "Africa/Bamako");
  fuzz(-74.8330, -176.3787, "Etc/GMT+12");
  fuzz( 72.6325,  -90.0358, "Etc/GMT+6");
  fuzz( 23.4670,   42.9883, "Asia/Riyadh");
  fuzz(-23.3307,  -36.6736, "Etc/GMT+2");
  fuzz( 41.6232,  -84.7897, "America/New_York");
  fuzz( -3.6548, -172.1271, "Etc/GMT+11");
  fuzz(-56.7157, -120.3445, "Etc/GMT+8");
  fuzz(-72.0407,   -5.3540, "Etc/GMT");
  fuzz( 11.2160, -174.2674, "Etc/GMT+12");
  fuzz(-71.2186,  138.4679, "Etc/GMT-9");
  fuzz(-21.5618,  -26.6589, "Etc/GMT+2");
  fuzz( 64.0877,   20.1457, "Europe/Stockholm");
  fuzz(-54.1129, -153.1340, "Etc/GMT+10");
  fuzz(-85.6236, -132.0119, "Etc/GMT+9");
  fuzz( 57.3703,  152.9167, "Etc/GMT-10");
  fuzz(-89.9531,    8.2339, "Etc/GMT-1");
  fuzz( -1.1746, -112.0468, "Etc/GMT+7");
  fuzz(-59.7438,  167.7799, "Etc/GMT-11");
  fuzz(-49.6988,   89.0456, "Etc/GMT-6");
  fuzz( 86.0901,   19.5626, "Etc/GMT-1");
  fuzz(  3.3483, -100.8079, "Etc/GMT+7");
  fuzz(-58.2424,  136.0591, "Etc/GMT-9");
  fuzz( 29.3704,  106.9562, "Asia/Chongqing");
  fuzz(-84.9806,  125.7324, "Etc/GMT-8");
  fuzz( 41.7189,  -22.0077, "Etc/GMT+1");
  fuzz( 83.8427, -115.9661, "Etc/GMT+8");
  fuzz( 16.7390,  -82.6748, "Etc/GMT+6");
  fuzz( -7.5542,  -89.2415, "Etc/GMT+6");
  fuzz( 11.4954, -155.9714, "Etc/GMT+10");
  fuzz( 21.1236,  -83.1222, "Etc/GMT+6");
  fuzz(-21.5588,   87.3124, "Etc/GMT-6");
  fuzz( 14.6190, -132.4092, "Etc/GMT+9");
  fuzz(-38.3104, -168.7639, "Etc/GMT+11");
  fuzz( 73.5927, -115.9105, "America/Yellowknife");
  fuzz( 76.7177, -112.4223, "Etc/GMT+7");
  fuzz(-70.0040,   72.3979, "Etc/GMT-5");
  fuzz( 31.5208,  150.4342, "Etc/GMT-10");
  fuzz(  9.6199,   43.2907, "Africa/Addis_Ababa");
  fuzz( 51.8279,  -84.3882, "America/Toronto");
  fuzz( 36.3362, -163.7315, "Etc/GMT+11");
  fuzz(-24.7524,   60.1816, "Etc/GMT-4");
  fuzz( 53.9024,  147.1506, "Etc/GMT-10");
  fuzz(-53.6305, -149.3842, "Etc/GMT+10");
  fuzz(-14.2636, -154.8864, "Etc/GMT+10");
  fuzz( 56.5034, -108.7968, "America/Regina");
  fuzz( 15.8153,  130.7902, "Etc/GMT-9");
  fuzz( 28.0192,  -75.5162, "Etc/GMT+5");
  fuzz(-78.2147, -174.7646, "Etc/GMT+12");
  fuzz(-62.0733,  -72.7888, "Etc/GMT+5");
  fuzz( 18.2057, -171.1562, "Etc/GMT+11");
  fuzz( 25.9262,  173.4059, "Etc/GMT-12");
  fuzz( 75.4868, -163.2644, "Etc/GMT+11");
  fuzz(-66.1448,  114.5911, "Etc/GMT-8");
  fuzz( 41.1409, -163.2371, "Etc/GMT+11");
  fuzz( 55.2477,   64.4429, "Asia/Yekaterinburg");
  fuzz( 86.2682, -157.3478, "Etc/GMT+10");
  fuzz( 79.9054,  -80.5558, "America/Iqaluit");
  fuzz( 11.0371,  162.8276, "Etc/GMT-11");
  fuzz( 68.1178,  137.7878, "Asia/Vladivostok");
  fuzz(-22.8997,   92.8684, "Etc/GMT-6");
  fuzz( 11.9341,  130.0794, "Etc/GMT-9");
  fuzz(-47.3126,  -92.9196, "Etc/GMT+6");
  fuzz( 15.0508, -133.3594, "Etc/GMT+9");
  fuzz( 88.5362, -174.6178, "Etc/GMT+12");
  fuzz( 44.4939,  -49.5772, "Etc/GMT+3");
  fuzz(-14.1554,  -28.7765, "Etc/GMT+2");
  fuzz( 75.4235,  140.6829, "Asia/Vladivostok");
  fuzz( 13.7783,  159.7451, "Etc/GMT-11");
  fuzz(-50.7094, -127.2529, "Etc/GMT+8");
  fuzz(-25.2425,  -83.6703, "Etc/GMT+6");
  fuzz( 25.1553,   30.5491, "Africa/Cairo");
  fuzz(-52.5143,   72.5869, "Etc/GMT-5");
  fuzz(-22.0502, -145.5635, "Etc/GMT+10");
  fuzz( 57.5382,   69.7678, "Asia/Yekaterinburg");
  fuzz(-20.1855,  -11.9931, "Etc/GMT+1");
  fuzz( 19.2966,   13.2915, "Africa/Niamey");
  fuzz( -5.6432,  173.1881, "Etc/GMT-12");
  fuzz(-29.3300,  -51.9941, "America/Sao_Paulo");
  fuzz( 68.4663,  137.8967, "Asia/Vladivostok");
  fuzz( 73.0884, -110.5937, "Etc/GMT+7");
  fuzz(-86.8772,   64.4912, "Etc/GMT-4");
  fuzz(-50.2156,  164.6682, "Etc/GMT-11");
  fuzz( 36.4490,  149.4624, "Etc/GMT-10");
  fuzz( 65.0498,   43.3195, "Europe/Moscow");
  fuzz(-44.3248,   90.2323, "Etc/GMT-6");
  fuzz( 56.5933,   91.5732, "Asia/Krasnoyarsk");
  fuzz(-89.2634, -151.1126, "Etc/GMT+10");
  fuzz(-43.8629, -136.8634, "Etc/GMT+9");
  fuzz(-88.4854,  -37.1587, "Etc/GMT+2");
  fuzz( 60.5847,  -13.0385, "Etc/GMT+1");
  fuzz(-48.7679,  168.0364, "Etc/GMT-11");
  fuzz( 63.4242,  153.9570, "Asia/Magadan");
  fuzz(  8.7187,   98.1291, "Etc/GMT-7");
  fuzz( 60.5414,  102.2830, "Asia/Krasnoyarsk");
  fuzz(-74.9941,   42.8487, "Etc/GMT-3");
  fuzz(-75.3446,  143.7784, "Etc/GMT-10");
  fuzz(-60.7719,  -26.1028, "Etc/GMT+2");
  fuzz( 53.0937,  -40.7710, "Etc/GMT+3");
  fuzz( 25.8468,  142.4140, "Etc/GMT-9");
  fuzz(-35.2768, -152.6489, "Etc/GMT+10");
  fuzz( 49.8855,   -0.0062, "Etc/GMT");
  fuzz( 78.2319,  -35.9009, "America/Godthab");
  fuzz( 50.4043,   20.1115, "Europe/Warsaw");
  fuzz( 67.7007, -139.1173, "America/Whitehorse");
  fuzz(-80.3098,   12.5777, "Etc/GMT-1");
  fuzz(-68.4195,   47.0201, "Etc/GMT-3");
  fuzz(-52.2105,   75.5462, "Etc/GMT-5");
  fuzz( 46.7656,   96.6875, "Asia/Hovd");
  fuzz( 37.7502, -126.1812, "Etc/GMT+8");
  fuzz(-89.4079,  -84.0891, "Etc/GMT+6");
  fuzz( 32.1598, -138.4990, "Etc/GMT+9");
  fuzz(-24.5928,  -99.7130, "Etc/GMT+7");
  fuzz( 73.8296,  -70.1278, "Etc/GMT+5");
  fuzz(-37.2552,  177.4493, "Etc/GMT-12");
  fuzz(-69.5045, -103.8183, "Etc/GMT+7");
  fuzz(-48.9148, -174.5151, "Etc/GMT+12");
  fuzz(-22.5825,   29.4276, "Africa/Johannesburg");
  fuzz(  1.7595,   85.4956, "Etc/GMT-6");
  fuzz(-54.5250,  164.1170, "Etc/GMT-11");
  fuzz(-55.1794, -130.6163, "Etc/GMT+9");
  fuzz( 59.9827,   92.8622, "Asia/Krasnoyarsk");
  fuzz( 32.2351,   74.7128, "Asia/Karachi");
  fuzz( 44.7867, -134.8299, "Etc/GMT+9");
  fuzz( -4.1111,   47.0072, "Etc/GMT-3");
  fuzz( 81.5336,  -86.4839, "America/Rankin_Inlet");
  fuzz( 77.1564,  -25.3151, "America/Godthab");
  fuzz(-18.4327, -168.5258, "Etc/GMT+11");
  fuzz(-79.4218,  164.4297, "Etc/GMT-11");
  fuzz(-13.4475,   10.6207, "Etc/GMT-1");
  fuzz(-20.0760, -122.1290, "Etc/GMT+8");
  fuzz(-32.9915,   87.8161, "Etc/GMT-6");
  fuzz(-24.5374,  160.7438, "Etc/GMT-11");
  fuzz( 40.7495,   34.3622, "Europe/Istanbul");
  fuzz(-21.5031, -119.0237, "Etc/GMT+8");
  fuzz(-10.0355, -166.7542, "Etc/GMT+11");
  fuzz( 15.0723, -122.7312, "Etc/GMT+8");
  fuzz(-71.2703,  -13.3404, "Etc/GMT+1");
  fuzz(-58.5275,  108.5717, "Etc/GMT-7");
  fuzz(-53.8113, -125.7197, "Etc/GMT+8");
  fuzz( 34.2004,   91.9447, "Asia/Urumqi");
  fuzz( 89.0599,   99.6301, "Etc/GMT-7");
  fuzz( 86.4796,   77.2978, "Etc/GMT-5");
  fuzz( 82.1272,   28.3962, "Etc/GMT-2");
  fuzz(-42.9845, -137.7829, "Etc/GMT+9");
  fuzz( 43.1564,  127.0682, "Asia/Harbin");
  fuzz( 12.8429, -153.8619, "Etc/GMT+10");
  fuzz( 10.9640, -142.7179, "Etc/GMT+10");
  fuzz(-61.5993,  113.3539, "Etc/GMT-8");
  fuzz( -5.2011,  125.1439, "Etc/GMT-8");
  fuzz(-12.6167,  -54.5727, "America/Cuiaba");
  fuzz( 26.5547, -100.3505, "America/Monterrey");
  fuzz(-34.9181, -142.7945, "Etc/GMT+10");
  fuzz(-89.6618,   16.4234, "Etc/GMT-1");
  fuzz( 80.6792, -169.4625, "Etc/GMT+11");
  fuzz(-37.1692,   54.4284, "Etc/GMT-4");
  fuzz( 12.1720, -107.1989, "Etc/GMT+7");
  fuzz( 43.4997,  118.0167, "Asia/Shanghai");
  fuzz(-12.6220,  167.1002, "Etc/GMT-11");
  fuzz( 48.2616,   20.3343, "Europe/Budapest");
  fuzz( 49.7049,  147.5895, "Etc/GMT-10");
  fuzz( 44.7708,   44.7429, "Europe/Moscow");
  fuzz(-52.3028, -178.9677, "Etc/GMT+12");
  fuzz( 79.6364,   28.5803, "Etc/GMT-2");
  fuzz(-39.7593, -133.0711, "Etc/GMT+9");
  fuzz(-13.2011,  175.2144, "Etc/GMT-12");
  fuzz( 48.3448,  108.2238, "Asia/Ulaanbaatar");
  fuzz( 29.8250, -131.8915, "Etc/GMT+9");
  fuzz(-31.0506,  161.6490, "Etc/GMT-11");
  fuzz( 42.6143,  -23.3723, "Etc/GMT+2");
  fuzz(  7.4350, -144.8914, "Etc/GMT+10");
  fuzz( 82.4296,   33.9369, "Etc/GMT-2");
  fuzz( 11.8781,  -54.0660, "Etc/GMT+4");
  fuzz(-43.6135,  -16.8970, "Etc/GMT+1");
  fuzz( 77.4182,   30.1922, "Etc/GMT-2");
  fuzz( 78.1638,  148.1879, "Etc/GMT-10");
  fuzz(-63.4112,  -52.1439, "Etc/GMT+3");
  fuzz(  5.5784, -138.9885, "Etc/GMT+9");
  fuzz( 33.0640,   20.2569, "Etc/GMT-1");
  fuzz(-79.5273,   82.9817, "Etc/GMT-6");
  fuzz( -1.5468,  -16.9745, "Etc/GMT+1");
  fuzz( 30.0386,  147.7821, "Etc/GMT-10");
  fuzz(-78.2903,  -35.3334, "Etc/GMT+2");
  fuzz(-11.5467,  -14.6391, "Etc/GMT+1");
  fuzz( 54.1347, -123.4773, "America/Vancouver");
  fuzz(-16.0532,  102.4476, "Etc/GMT-7");
  fuzz(-12.3028,   -4.0804, "Etc/GMT");
  fuzz(-69.8519, -138.2314, "Etc/GMT+9");
  fuzz(-31.0827, -106.0773, "Etc/GMT+7");
  fuzz(-84.5917,  128.7858, "Etc/GMT-9");
  fuzz( 37.1042,   -8.4274, "Europe/Lisbon");
  fuzz(-72.1359, -105.6056, "Etc/GMT+7");
  fuzz(-44.7893,   43.8487, "Etc/GMT-3");
  fuzz(-60.6653,  -15.1823, "Etc/GMT+1");
  fuzz( 79.8894,   17.3457, "Arctic/Longyearbyen");
  fuzz( 27.7678,  -27.0347, "Etc/GMT+2");
  fuzz(-71.7419,  148.4417, "Etc/GMT-10");
  fuzz(-78.9742,    9.6558, "Etc/GMT-1");
  fuzz( 63.2507,  -46.7969, "America/Godthab");
  fuzz( 72.3179,  -61.1947, "Etc/GMT+4");
  fuzz( 22.3104,  -22.4560, "Etc/GMT+1");
  fuzz( 88.0449,  -17.8014, "Etc/GMT+1");
  fuzz(-71.3701,  160.8762, "Etc/GMT-11");
  fuzz( 56.9055,  143.6015, "Etc/GMT-10");
  fuzz( 24.5184,  -88.2035, "Etc/GMT+6");
  fuzz( 37.1368,   26.6473, "Etc/GMT-2");
  fuzz(-33.1729,  103.9922, "Etc/GMT-7");
  fuzz(-45.6075,   -4.6891, "Etc/GMT");
  fuzz( -1.9246,   29.0612, "Africa/Lubumbashi");
  fuzz( 84.9484,  -36.4336, "Etc/GMT+2");
  fuzz(-82.4913,  -87.9753, "Etc/GMT+6");
  fuzz(-12.3557,  -53.4448, "America/Cuiaba");
  fuzz(-34.3079,  134.6241, "Etc/GMT-9");
  fuzz(-73.6477,    7.1752, "Etc/GMT");
  fuzz(-20.4984, -152.2024, "Etc/GMT+10");
  fuzz(-27.3542,  -49.1180, "America/Sao_Paulo");
  fuzz( 62.9927,   24.7490, "Europe/Helsinki");
  fuzz( -5.1514,  -16.2535, "Etc/GMT+1");
  fuzz(-46.7249,  -87.2317, "Etc/GMT+6");
  fuzz(-63.2774,  133.8986, "Etc/GMT-9");
  fuzz( 76.0195,  -49.4057, "America/Godthab");
  fuzz( 14.1445,    3.7444, "Africa/Niamey");
  fuzz( 85.5795,  -15.1914, "Etc/GMT+1");
  fuzz(-36.9716, -135.8226, "Etc/GMT+9");
  fuzz(-75.9338,  -32.7643, "Etc/GMT+2");
  fuzz(-86.6595,  169.5617, "Etc/GMT-11");
  fuzz( 14.4858,   19.3595, "Africa/Ndjamena");
  fuzz(-43.6033,   20.2037, "Etc/GMT-1");
  fuzz(-61.4322,  -93.6202, "Etc/GMT+6");
  fuzz( -0.5989, -164.1203, "Etc/GMT+11");
  fuzz(-11.4764, -133.1308, "Etc/GMT+9");
  fuzz( 26.4453, -150.6797, "Etc/GMT+10");
  fuzz( -8.1545, -161.7078, "Etc/GMT+11");
  fuzz(-78.5446, -148.4449, "Etc/GMT+10");
  fuzz(-63.2994,   79.1661, "Etc/GMT-5");
  fuzz(  8.5186,   11.5768, "Africa/Lagos");
  fuzz( 16.1586,   51.0247, "Asia/Aden");
  fuzz(-37.2227,    8.5600, "Etc/GMT-1");
  fuzz( 83.0942,  107.7635, "Etc/GMT-7");
  fuzz(-64.1064,   87.4708, "Etc/GMT-6");
  fuzz(-54.1376,   39.5671, "Etc/GMT-3");
  fuzz( 35.6008, -177.7024, "Etc/GMT+12");
  fuzz( 88.2911, -104.2649, "Etc/GMT+7");
  fuzz(-67.9614, -139.1570, "Etc/GMT+9");
  fuzz( 46.6198,   -8.0001, "Etc/GMT+1");
  fuzz(-33.5507,    8.6515, "Etc/GMT-1");
  fuzz(-76.4642, -178.1620, "Etc/GMT+12");
  fuzz( -4.0933,  171.2472, "Etc/GMT-11");
  fuzz(-89.7544,  140.2192, "Etc/GMT-9");
  fuzz(-81.2861,  136.2004, "Etc/GMT-9");
  fuzz( 57.3549,  171.7579, "Etc/GMT-11");
  fuzz(-47.5775,  -44.4270, "Etc/GMT+3");
  fuzz(-54.3709,   47.9654, "Etc/GMT-3");
  fuzz(-38.8873,  108.2892, "Etc/GMT-7");
  fuzz( 56.5211,   46.9765, "Europe/Moscow");
  fuzz( 37.3835, -127.8680, "Etc/GMT+9");
  fuzz( 86.9818,   94.7990, "Etc/GMT-6");
  fuzz(-41.4317,  176.3440, "Etc/GMT-12");
  fuzz( -0.8225,  122.7093, "Asia/Makassar");
  fuzz(-25.3730,  155.2118, "Etc/GMT-10");
  fuzz(  9.6464, -141.2880, "Etc/GMT+9");
  fuzz( 73.9805,   47.5226, "Etc/GMT-3");
  fuzz( 32.2315,  -79.2218, "Etc/GMT+5");
  fuzz(-82.2606,   56.7828, "Etc/GMT-4");
  fuzz(-65.1192, -128.7797, "Etc/GMT+9");
  fuzz( -3.7957,  120.7048, "Etc/GMT-8");
  fuzz( 26.9745,  -92.8187, "Etc/GMT+6");
  fuzz(-62.8687,   96.9182, "Etc/GMT-6");
  fuzz(-72.3563,  161.4798, "Etc/GMT-11");
  fuzz(-76.9462,   33.2865, "Etc/GMT-2");
  fuzz( 55.8338, -156.0769, "Etc/GMT+10");
  fuzz(-52.7142, -103.7189, "Etc/GMT+7");
  fuzz( 86.3510, -146.5498, "Etc/GMT+10");
  fuzz( 31.3740,   78.8367, "Asia/Kashgar");
  fuzz(-81.4231,   28.0945, "Etc/GMT-2");
  fuzz(-55.9175,   87.5042, "Etc/GMT-6");
  fuzz( 27.7822, -148.7617, "Etc/GMT+10");
  fuzz(-34.7375,  172.4330, "Etc/GMT-11");
  fuzz( 71.5231,  -10.4581, "Etc/GMT+1");
  fuzz( -3.0522,  -91.6739, "Etc/GMT+6");
  fuzz(-72.3607,  -59.0333, "Etc/GMT+4");
  fuzz( 60.0522,  -78.3931, "Etc/GMT+5");
  fuzz( -2.6749,  -33.8010, "Etc/GMT+2");
  fuzz(-52.3122,   78.8787, "Etc/GMT-5");
  fuzz( 71.7943,  142.9243, "Asia/Vladivostok");
  fuzz(-50.0940,   17.8104, "Etc/GMT-1");
  fuzz(-56.0490,  -29.4447, "Etc/GMT+2");
  fuzz(-73.7319,  -68.4898, "Etc/GMT+5");
  fuzz( -9.9157,  -19.8829, "Etc/GMT+1");
  fuzz(  8.5647,  -60.4838, "Etc/GMT+4");
  fuzz( 12.9959,  121.6825, "Etc/GMT-8");
  fuzz( -4.6304,  155.1870, "Etc/GMT-10");
  fuzz( 53.4800,  102.6862, "Asia/Irkutsk");
  fuzz( 54.4724,   35.8859, "Europe/Moscow");
  fuzz( 16.1258, -156.9914, "Etc/GMT+10");
  fuzz(-62.8763,  -73.5744, "Etc/GMT+5");
  fuzz( 42.6423,   47.3439, "Europe/Moscow");
  fuzz(-35.0331,  133.4871, "Etc/GMT-9");
  fuzz(-49.0577,   38.4008, "Etc/GMT-3");
  fuzz(-70.9306,  -82.1007, "Etc/GMT+5");
  fuzz( 65.2120,   36.4643, "Etc/GMT-2");
  fuzz( 21.3766,   -9.0809, "Africa/Nouakchott");
  fuzz( 88.5692, -117.7727, "Etc/GMT+8");
  fuzz( 41.6508, -168.8401, "Etc/GMT+11");
  fuzz(-21.9133, -171.4179, "Etc/GMT+11");
  fuzz( 42.2592,   32.7058, "Etc/GMT-2");
  fuzz(  2.9200,  -17.4692, "Etc/GMT+1");
  fuzz(-70.4495,  114.6971, "Etc/GMT-8");
  fuzz( 16.7530,   67.4395, "Etc/GMT-4");
  fuzz( 35.4466,   85.8077, "Asia/Urumqi");
  fuzz( 15.3113,   32.8385, "Africa/Khartoum");
  fuzz( -0.9303,  -61.5420, "America/Manaus");
  fuzz( 65.1811,  -85.3929, "America/Coral_Harbour");
  fuzz( 84.9598,   41.8590, "Etc/GMT-3");
  fuzz(-68.6451,    9.1237, "Etc/GMT-1");
  fuzz( 40.0440, -145.5159, "Etc/GMT+10");
  fuzz(  8.7334,  104.6102, "Etc/GMT-7");
  fuzz(-67.9762,   70.3156, "Etc/GMT-5");
  fuzz( 41.3979,  109.2824, "Asia/Chongqing");
  fuzz( 61.4208,  165.6336, "Asia/Kamchatka");
  fuzz(-77.5024,   82.1436, "Etc/GMT-5");
  fuzz( 31.5990,  110.1621, "Asia/Shanghai");
  fuzz(-58.3354,  -12.3140, "Etc/GMT+1");
  fuzz(-25.9807,   26.9300, "Africa/Johannesburg");
  fuzz(-31.7607,  169.1474, "Etc/GMT-11");
  fuzz( 61.7306,  -48.6246, "America/Godthab");
  fuzz(-69.9738, -129.9433, "Etc/GMT+9");
  fuzz(-64.0966, -141.4749, "Etc/GMT+9");
  fuzz( 11.1543,  101.2214, "Etc/GMT-7");
  fuzz( 84.0305,  166.9878, "Etc/GMT-11");
  fuzz( 35.5288,   32.0158, "Etc/GMT-2");
  fuzz( 64.2152,  124.0541, "Asia/Yakutsk");
  fuzz(-71.2026,  -86.4539, "Etc/GMT+6");
  fuzz(-46.1385,  -72.9657, "America/Santiago");
  fuzz(-33.9614,  152.6161, "Etc/GMT-10");
  fuzz(-42.9107,    0.7922, "Etc/GMT");
  fuzz(  2.7118, -129.5926, "Etc/GMT+9");
  fuzz( -7.6608,  -85.5638, "Etc/GMT+6");
  fuzz( 15.8589,   24.5199, "Africa/Khartoum");
  fuzz( 56.0054,   60.8903, "Asia/Yekaterinburg");
  fuzz(-20.2249, -115.5362, "Etc/GMT+8");
  fuzz( 61.4232, -131.4265, "America/Whitehorse");
  fuzz(-55.8778,  124.7907, "Etc/GMT-8");
  fuzz( 37.2307,  -22.5235, "Etc/GMT+2");
  fuzz( 60.1848, -122.0054, "America/Yellowknife");
  fuzz( 70.5339,   41.9048, "Etc/GMT-3");
  fuzz(  0.6378, -137.3749, "Etc/GMT+9");
  fuzz(  3.7764,    3.9752, "Etc/GMT");
  fuzz( 42.6386,  -57.4933, "Etc/GMT+4");
  fuzz( 51.5442, -105.1728, "America/Regina");
  fuzz( -1.7514,  107.3429, "Etc/GMT-7");
  fuzz(-47.7606,  -45.4272, "Etc/GMT+3");
  fuzz( 35.5202, -147.3591, "Etc/GMT+10");
  fuzz(  2.9178,  149.3160, "Etc/GMT-10");
  fuzz( 21.8337,  -89.7355, "Etc/GMT+6");
  fuzz( 43.8244,  -96.6180, "America/Chicago");
  fuzz( -6.8222, -129.0506, "Etc/GMT+9");
  fuzz( 62.6568,   77.4446, "Asia/Yekaterinburg");
  fuzz( 72.0346,  -32.6102, "America/Godthab");
  fuzz( 14.0688,  -13.6619, "Africa/Dakar");
  fuzz( 79.5181,  -25.8663, "America/Godthab");
  fuzz(-61.1528,  -10.2912, "Etc/GMT+1");
  fuzz(-19.4198,  -23.9760, "Etc/GMT+2");
  fuzz(-66.3533,  -90.0838, "Etc/GMT+6");
  fuzz( 59.8240,   37.2919, "Europe/Moscow");
  fuzz( 47.2100,  122.8452, "Asia/Harbin");
  fuzz( 82.7460,  101.3690, "Etc/GMT-7");
  fuzz( 22.6333,  -62.1330, "Etc/GMT+4");
  fuzz( -9.1447,   69.7236, "Etc/GMT-5");
  fuzz( 11.1573,  174.2912, "Etc/GMT-12");
  fuzz( 20.0870, -147.5527, "Etc/GMT+10");
  fuzz(-17.5707, -148.2767, "Etc/GMT+10");
  fuzz( 51.9605,  -50.5536, "Etc/GMT+3");
  fuzz( 73.8297,  134.3293, "Etc/GMT-9");
  fuzz(-82.7011,  -75.3582, "Etc/GMT+5");
  fuzz(  9.1754,  -76.0658, "America/Bogota");
  fuzz(-40.7375,  106.0410, "Etc/GMT-7");
  fuzz( -3.3148,   38.7519, "Africa/Nairobi");
  fuzz( -9.1244,   69.8665, "Etc/GMT-5");
  fuzz(-62.7191,  156.9598, "Etc/GMT-10");
  fuzz(-30.8390,  -61.0529, "America/Argentina/Cordoba");
  fuzz(-61.3252,  -25.5167, "Etc/GMT+2");
  fuzz( 14.7521, -156.6659, "Etc/GMT+10");
  fuzz( 65.6241,    4.0688, "Etc/GMT");
  fuzz( 77.3716,  -56.5280, "America/Godthab");
  fuzz( 45.6857,  -58.4252, "Etc/GMT+4");
  fuzz( 25.4612,   16.3495, "Africa/Tripoli");
  fuzz( 49.2977, -125.2356, "America/Vancouver");
  fuzz(  3.8288,  -26.6819, "Etc/GMT+2");
  fuzz(-53.1175,  -67.9350, "Etc/GMT+5");
  fuzz( 18.4695,   27.3104, "Africa/Khartoum");
  fuzz(-73.7466,  153.5628, "Etc/GMT-10");
  fuzz( 72.3550,   25.6240, "Etc/GMT-2");
  fuzz( 65.4723,  167.7756, "Asia/Anadyr");
  fuzz(-64.0315,  128.0117, "Etc/GMT-9");
  fuzz( 53.0989,   40.2981, "Europe/Moscow");
  fuzz( 46.0498, -119.7057, "America/Los_Angeles");
  fuzz(-38.6204,   54.4505, "Etc/GMT-4");
  fuzz( 31.8935,  148.8684, "Etc/GMT-10");
  fuzz(-35.1627, -111.3978, "Etc/GMT+7");
  fuzz(-43.1839,  116.7449, "Etc/GMT-8");
  fuzz( 29.8394,  -54.9341, "Etc/GMT+4");
  fuzz( 33.4187,   40.2683, "Asia/Baghdad");
  fuzz(-30.8786, -107.2129, "Etc/GMT+7");
  fuzz(-46.8805,    5.0285, "Etc/GMT");
  fuzz(-49.6791,   -2.5995, "Etc/GMT");
  fuzz(-59.0425,  102.1188, "Etc/GMT-7");
  fuzz(-37.3424,   72.9998, "Etc/GMT-5");
  fuzz( 17.9706,  -54.8157, "Etc/GMT+4");
  fuzz(-16.7656,  138.1749, "Australia/Brisbane");
  fuzz( -4.8337,  154.1934, "Etc/GMT-10");
  fuzz( 46.6549,   33.7897, "Europe/Kiev");
  fuzz( 81.6872,  161.2389, "Etc/GMT-11");
  fuzz(-76.8516,  -95.1636, "Etc/GMT+6");
  fuzz( 67.5675,  115.0571, "Asia/Yakutsk");
  fuzz( 54.2140,   45.7523, "Europe/Moscow");
  fuzz(-26.1115, -154.3603, "Etc/GMT+10");
  fuzz(-16.6440,   80.9147, "Etc/GMT-5");
  fuzz(-40.6276,   50.4456, "Etc/GMT-3");
  fuzz( 73.7215, -172.6334, "Etc/GMT+12");
  fuzz( 87.2671,  -40.3414, "Etc/GMT+3");
  fuzz(-76.9126,   87.6522, "Etc/GMT-6");
  fuzz( 57.2101,  142.8496, "Etc/GMT-10");
  fuzz(-15.4168,   27.5488, "Africa/Lusaka");
  fuzz(-71.5996, -171.3676, "Etc/GMT+11");
  fuzz(-40.1341,   74.9762, "Etc/GMT-5");
  fuzz( 20.8773,  127.8482, "Etc/GMT-9");
  fuzz( 67.2546,   11.8626, "Etc/GMT-1");
  fuzz( 72.0585,   94.0572, "Asia/Krasnoyarsk");
  fuzz( 43.7057,  -79.6802, "America/Toronto");
  fuzz(-12.8489,  105.3215, "Etc/GMT-7");
  fuzz( 68.7574,   27.1326, "Europe/Helsinki");
  fuzz(-25.1354,   74.8522, "Etc/GMT-5");
  fuzz( 47.9892,  138.5052, "Asia/Vladivostok");
  fuzz(-41.1254,   -2.9667, "Etc/GMT");
  fuzz(-45.2930,  129.7909, "Etc/GMT-9");
  fuzz(-14.8460,  114.9493, "Etc/GMT-8");
  fuzz( -7.7381,  -89.8140, "Etc/GMT+6");
  fuzz(-54.4681,    8.8432, "Etc/GMT-1");
  fuzz( 88.7202,  -91.8432, "Etc/GMT+6");
  fuzz(-11.8112,   93.2587, "Etc/GMT-6");
  fuzz(-21.5884, -143.7034, "Etc/GMT+10");
  fuzz( 58.8739,   88.8491, "Asia/Krasnoyarsk");
  fuzz( 19.0343, -108.3572, "Etc/GMT+7");
  fuzz(-85.8668,  -11.4048, "Etc/GMT+1");
  fuzz(-84.5269,  102.4650, "Etc/GMT-7");
  fuzz(-38.9908,   82.7087, "Etc/GMT-6");
  fuzz(-36.5344, -174.4649, "Etc/GMT+12");
  fuzz(-22.1456,  -74.2190, "Etc/GMT+5");
  fuzz( 67.9233, -167.1054, "Etc/GMT+11");
  fuzz( 49.5039,  106.2301, "Asia/Ulaanbaatar");
  fuzz( 32.5627,   31.1829, "Etc/GMT-2");
  fuzz( -0.4175,  127.2838, "Etc/GMT-8");
  fuzz(-45.8369,  101.6517, "Etc/GMT-7");
  fuzz( -2.1097,   57.6494, "Etc/GMT-4");
  fuzz( 47.1250,   86.2943, "Asia/Urumqi");
  fuzz(-14.0072,   60.2615, "Etc/GMT-4");
  fuzz(-30.7504,  -65.1035, "America/Argentina/Cordoba");
  fuzz(-34.9229,   20.6797, "Etc/GMT-1");
  fuzz(-63.6657, -138.7420, "Etc/GMT+9");
  fuzz(-59.9815,   21.0909, "Etc/GMT-1");
  fuzz(-85.8542,   30.6757, "Etc/GMT-2");
  fuzz( 68.4592, -103.9283, "Etc/GMT+7");
  fuzz( 76.6595,  156.8853, "Etc/GMT-10");
  fuzz(  5.2708,  -51.3656, "Etc/GMT+3");
  fuzz( 40.9909,  -37.4999, "Etc/GMT+2");
  fuzz( 58.0723,  179.5577, "Etc/GMT-12");
  fuzz(-28.5256,  -73.7800, "Etc/GMT+5");
  fuzz(-78.1239,   72.3643, "Etc/GMT-5");
  fuzz(-41.9253,  152.5098, "Etc/GMT-10");
  fuzz( 73.0064,   98.4606, "Asia/Krasnoyarsk");
  fuzz( 67.5976,  -58.7085, "Etc/GMT+4");
  fuzz( 72.9200,  -53.8420, "America/Godthab");
  fuzz( 10.3492,  -23.0256, "Etc/GMT+2");
  fuzz( 42.5593, -143.0857, "Etc/GMT+10");
  fuzz( 33.9540,  -84.6719, "America/New_York");
  fuzz( -9.6293, -159.1713, "Etc/GMT+11");
  fuzz( 70.2102,  109.2729, "Asia/Krasnoyarsk");
  fuzz( 14.5076,   76.2365, "Asia/Kolkata");
  fuzz( 72.0270,   10.0098, "Etc/GMT-1");
  fuzz( 12.8661, -152.3316, "Etc/GMT+10");
  fuzz(-17.0533, -134.5707, "Etc/GMT+9");
  fuzz( 29.1668,   28.7916, "Africa/Cairo");
  fuzz(-78.6124,  127.0049, "Etc/GMT-8");
  fuzz( -6.3410,   16.0039, "Africa/Luanda");
  fuzz(-37.0847, -140.5368, "Etc/GMT+9");
  fuzz( 84.0634,  -64.0498, "Etc/GMT+4");
  fuzz(-37.1920,   33.2560, "Etc/GMT-2");
  fuzz( 39.6055, -145.9370, "Etc/GMT+10");
  fuzz( 15.7965,   18.3872, "Africa/Ndjamena");
  fuzz(-69.9263,   69.7517, "Etc/GMT-5");
  fuzz( 42.2482,  -28.8198, "Etc/GMT+2");
  fuzz(-25.0767,  -25.9396, "Etc/GMT+2");
  fuzz(-86.7298,  -50.7536, "Etc/GMT+3");
  fuzz( 13.0889,  169.2752, "Etc/GMT-11");
  fuzz( -7.7214,  140.5180, "Asia/Jayapura");
  fuzz( 23.8358,   14.1805, "Africa/Tripoli");
  fuzz( -5.5183, -123.6722, "Etc/GMT+8");
  fuzz( -4.8307, -155.9385, "Etc/GMT+10");
  fuzz( 56.1999,  114.3054, "Asia/Irkutsk");
  fuzz( 69.5784,  -98.6182, "Etc/GMT+7");
  fuzz(-84.3373,  147.2975, "Etc/GMT-10");
  fuzz( 40.6756,   -3.1529, "Europe/Madrid");
  fuzz(-71.4498,   -9.8514, "Etc/GMT+1");
  fuzz( 46.6208, -110.5776, "America/Denver");
  fuzz(  7.5088, -154.1123, "Etc/GMT+10");
  fuzz( 33.8164,   -4.3187, "Africa/Casablanca");
  fuzz( 14.4046,  -65.4222, "Etc/GMT+4");
  fuzz(-27.9486,   91.1234, "Etc/GMT-6");
  fuzz(-89.0214,  133.0722, "Etc/GMT-9");
  fuzz( 27.8671,  160.6175, "Etc/GMT-11");
  fuzz( 19.4155,  -70.3931, "America/Santo_Domingo");
  fuzz( 70.7185,   11.9177, "Etc/GMT-1");
  fuzz(-79.8286,  133.2787, "Etc/GMT-9");
  fuzz(-85.5056, -118.8943, "Etc/GMT+8");
  fuzz( 63.9662,   27.2907, "Europe/Helsinki");
  fuzz(-46.6715,   11.9037, "Etc/GMT-1");
  fuzz( 30.4291,   -7.3296, "Africa/Casablanca");
  fuzz( -6.6112,    9.4073, "Etc/GMT-1");
  fuzz(-56.6165, -158.9073, "Etc/GMT+11");
  fuzz( 30.5112, -178.1934, "Etc/GMT+12");
  fuzz(-12.6378,  -57.5000, "America/Cuiaba");
  fuzz(-65.5140,    0.1722, "Etc/GMT");
  fuzz(-33.9631,  -73.2363, "Etc/GMT+5");
  fuzz(-26.3363,  -28.4172, "Etc/GMT+2");
  fuzz( 85.4608,  140.0439, "Etc/GMT-9");
  fuzz( -4.8398,  -13.4342, "Etc/GMT+1");
  fuzz( 85.8632,  171.3983, "Etc/GMT-11");
  fuzz(-21.3209,   49.5177, "Etc/GMT-3");
  fuzz( 26.8727,  109.0441, "Asia/Chongqing");
  fuzz( 27.9214,  -61.1026, "Etc/GMT+4");
  fuzz(-78.1267,  100.4239, "Etc/GMT-7");
  fuzz( 87.3767,  -40.4315, "Etc/GMT+3");
  fuzz( 89.2085,   58.7276, "Etc/GMT-4");
  fuzz(-53.8309, -123.2072, "Etc/GMT+8");
  fuzz(-82.1890,    9.6386, "Etc/GMT-1");
  fuzz(-73.1809, -102.3183, "Etc/GMT+7");
  fuzz(-68.6083, -147.7823, "Etc/GMT+10");
  fuzz( -3.9646,  -73.4212, "America/Lima");
  fuzz(-55.6376,  159.8976, "Etc/GMT-11");
  fuzz( 83.9240,  -79.2064, "Etc/GMT+5");
  fuzz( 59.0782,  134.1499, "Asia/Vladivostok");
  fuzz( 82.1359,    6.6758, "Etc/GMT");
  fuzz(-18.8768,  123.5026, "Australia/Perth");
  fuzz(-64.3415, -150.0677, "Etc/GMT+10");
  fuzz(-74.4234, -169.5974, "Etc/GMT+11");
  fuzz(-32.2041, -176.7416, "Etc/GMT+12");
  fuzz( 51.6408,  120.1441, "Asia/Shanghai");
  fuzz(-51.0467, -176.2886, "Etc/GMT+12");
  fuzz( 39.2615, -178.5689, "Etc/GMT+12");
  fuzz(-82.0954,   62.2052, "Etc/GMT-4");
  fuzz( 89.8802,   60.0389, "Etc/GMT-4");
  fuzz( -3.2149,  -60.7691, "America/Manaus");
  fuzz( 53.7076,  -53.3840, "Etc/GMT+4");
  fuzz( 59.0627,  -56.7458, "Etc/GMT+4");
  fuzz( 56.0306,   96.2819, "Asia/Krasnoyarsk");
  fuzz(-64.2737,  -56.4394, "Etc/GMT+4");
  fuzz(-65.6080,  105.5284, "Etc/GMT-7");
  fuzz(-59.5059, -107.6038, "Etc/GMT+7");
  fuzz( 61.3456, -154.6022, "America/Anchorage");
  fuzz(  5.4368,  112.4952, "Etc/GMT-7");
  fuzz(-44.3186, -114.3032, "Etc/GMT+8");
  fuzz( -3.6689,  -24.3147, "Etc/GMT+2");
  fuzz( 17.0363,   80.1072, "Asia/Kolkata");
  fuzz(  0.9171,  147.3798, "Etc/GMT-10");
  fuzz( 32.9800,  -84.4394, "America/New_York");
  fuzz(-37.2510,   73.0560, "Etc/GMT-5");
  fuzz(-37.1476, -107.8370, "Etc/GMT+7");
  fuzz(-77.5218,   30.9515, "Etc/GMT-2");
  fuzz( 69.7465,   88.1611, "Asia/Krasnoyarsk");
  fuzz(-66.3565,  -23.4963, "Etc/GMT+2");
  fuzz( 30.1065, -119.7944, "Etc/GMT+8");
  fuzz( -9.6634,   63.8048, "Etc/GMT-4");
  fuzz(-55.1922,  -78.5386, "Etc/GMT+5");
  fuzz(-54.6218,  124.7434, "Etc/GMT-8");
  fuzz( 29.5608,  -54.7671, "Etc/GMT+4");
  fuzz(-33.4434,  132.8539, "Etc/GMT-9");
  fuzz(-75.1184,  171.1542, "Etc/GMT-11");
  fuzz( 75.6530,   57.9007, "Etc/GMT-4");
  fuzz(-89.2499,    3.5857, "Etc/GMT");
  fuzz(-68.6773,  173.6353, "Etc/GMT-12");
  fuzz(  4.4212, -148.8851, "Etc/GMT+10");
  fuzz(-69.5487,   79.7107, "Etc/GMT-5");
  fuzz( 79.1462,   70.6346, "Etc/GMT-5");
  fuzz( -5.1399,   -4.7897, "Etc/GMT");
  fuzz(-55.3434, -176.6812, "Etc/GMT+12");
  fuzz(-34.1426,  152.3314, "Etc/GMT-10");
  fuzz(-29.7942,   40.1970, "Etc/GMT-3");
  fuzz(-10.0395,  -14.1923, "Etc/GMT+1");
  fuzz(-83.9661,  -46.4105, "Etc/GMT+3");
  fuzz(-41.3242,   48.2122, "Etc/GMT-3");
  fuzz(-63.2191,  116.9455, "Etc/GMT-8");
  fuzz(-79.6901,  178.4914, "Etc/GMT-12");
  fuzz(-83.3297,  -27.0718, "Etc/GMT+2");
  fuzz(  3.1478,   -8.8527, "Etc/GMT+1");
  fuzz(-56.4725,  118.1774, "Etc/GMT-8");
  fuzz( 44.8653,  153.9159, "Etc/GMT-10");
  fuzz(-24.7776,  133.3335, "Australia/Darwin");
  fuzz(-30.2585,   34.3424, "Etc/GMT-2");
  fuzz(-55.4455,  175.0634, "Etc/GMT-12");
  fuzz(-26.3535,  -14.0854, "Etc/GMT+1");
  fuzz( 76.5936,   27.2636, "Etc/GMT-2");
  fuzz( 52.2638,   23.4595, "Europe/Minsk");
  fuzz(-78.4853,   11.3037, "Etc/GMT-1");
  fuzz(-19.4206,   96.7183, "Etc/GMT-6");
  fuzz(-51.8186,   77.7054, "Etc/GMT-5");
  fuzz(-53.2273, -158.2923, "Etc/GMT+11");
  fuzz(-53.0973, -128.2275, "Etc/GMT+9");
  fuzz(-17.0907,  118.6095, "Etc/GMT-8");
  fuzz(  6.0803,   33.7236, "Africa/Juba");
  fuzz( 58.7861,  -23.0571, "Etc/GMT+2");
  fuzz( 85.5213,  -61.4240, "Etc/GMT+4");
  fuzz(  1.3313, -146.8096, "Etc/GMT+10");
  fuzz(-48.9622,   -4.1365, "Etc/GMT");
  fuzz(-28.3594,  170.5297, "Etc/GMT-11");
  fuzz( 46.2339,  118.3615, "Asia/Shanghai");
  fuzz(-55.7499, -128.0973, "Etc/GMT+9");
  fuzz(-31.8517,   19.9454, "Africa/Johannesburg");
  fuzz(-77.7177,   88.2876, "Etc/GMT-6");
  fuzz(-62.5578,  -57.1301, "Etc/GMT+4");
  fuzz(-42.4224, -109.0907, "Etc/GMT+7");
  fuzz(-45.4649,   33.0215, "Etc/GMT-2");
  fuzz( 28.4657,  110.0877, "Asia/Shanghai");
  fuzz( 31.4164, -162.3821, "Etc/GMT+11");
  fuzz(-27.6342, -107.6790, "Etc/GMT+7");
  fuzz( 16.4404,  -49.6069, "Etc/GMT+3");
  fuzz(-81.7568,  105.1419, "Etc/GMT-7");
  fuzz( -7.0809,  -81.3027, "Etc/GMT+5");
  fuzz( 20.0620,   90.6535, "Etc/GMT-6");
  fuzz(-81.9665,  119.8490, "Etc/GMT-8");
  fuzz( 40.1297,   63.6307, "Asia/Samarkand");
  fuzz(  4.2013,   84.7797, "Etc/GMT-6");
  fuzz(-32.2967, -115.8264, "Etc/GMT+8");
  fuzz(-19.1731,   14.5112, "Africa/Windhoek");
  fuzz( 56.6561,   54.9217, "Asia/Yekaterinburg");
  fuzz(-66.7705,  -62.8564, "Etc/GMT+4");
  fuzz(-67.1845, -142.5244, "Etc/GMT+10");
  fuzz( 71.3533,  -17.2790, "Etc/GMT+1");
  fuzz( 48.5194,   62.6996, "Asia/Aqtobe");
  fuzz(-82.9447,  -66.3350, "Etc/GMT+4");
  fuzz(  2.9623,  168.5922, "Etc/GMT-11");
  fuzz( 70.6848, -102.6733, "Etc/GMT+7");
  fuzz( 15.0813,  102.2842, "Asia/Bangkok");
  fuzz(-62.2867, -160.0436, "Etc/GMT+11");
  fuzz( -2.9155,  104.5851, "Asia/Jakarta");
  fuzz( 81.1789,  108.6737, "Etc/GMT-7");
  fuzz(-46.3377,   40.5191, "Etc/GMT-3");
  fuzz(-66.3127,  157.1511, "Etc/GMT-10");
  fuzz(-71.0475,  -79.0481, "Etc/GMT+5");
  fuzz(-35.1480,   41.1389, "Etc/GMT-3");
  fuzz(-50.8557,   91.7244, "Etc/GMT-6");
  fuzz( 56.6240,  116.2860, "Asia/Yakutsk");
  fuzz(-68.6024,  164.6458, "Etc/GMT-11");
  fuzz( 82.4580,   88.9539, "Etc/GMT-6");
  fuzz(-80.3412, -114.9623, "Etc/GMT+8");
  fuzz(-64.6325,   21.1022, "Etc/GMT-1");
  fuzz( 20.8734,   13.1134, "Africa/Niamey");
  fuzz( 30.7539,    4.9642, "Africa/Algiers");
  fuzz(-79.1078,  178.0281, "Etc/GMT-12");
  fuzz( 51.2865,  121.6765, "Asia/Shanghai");
  fuzz( -8.3519,   70.0993, "Etc/GMT-5");
  fuzz( 70.9767,   48.3127, "Etc/GMT-3");
  fuzz( 12.1136,  134.8624, "Etc/GMT-9");
  fuzz( 18.4527,    3.0800, "Africa/Bamako");
  fuzz(-61.4525,  -20.1718, "Etc/GMT+1");
  fuzz(-85.2873,  -42.3156, "Etc/GMT+3");
  fuzz(-62.6517,    8.2094, "Etc/GMT-1");
  fuzz( 42.7846,  -29.1573, "Etc/GMT+2");
  fuzz(-12.9176,  -51.8294, "America/Cuiaba");
  fuzz(-77.5125,   69.1833, "Etc/GMT-5");
  fuzz(-78.6758,  -94.2000, "Etc/GMT+6");
  fuzz( -9.8941,   31.4986, "Africa/Lusaka");
  fuzz(  0.9538,  145.9083, "Etc/GMT-10");
  fuzz(-54.6093,  131.3635, "Etc/GMT-9");
  fuzz( 51.1884,   72.5447, "Asia/Almaty");
  fuzz(-36.8834,  168.3115, "Etc/GMT-11");
  fuzz(-34.7990,   24.0946, "Etc/GMT-2");
  fuzz( 50.1720,  109.3305, "Asia/Yakutsk");
  fuzz( 31.6023,  -81.5271, "America/New_York");
  fuzz( -1.2999,  160.0939, "Etc/GMT-11");
  fuzz( 74.5168,  -78.7525, "Etc/GMT+5");
  fuzz( -2.9409,   69.1802, "Etc/GMT-5");
  fuzz(-54.7681,   49.5643, "Etc/GMT-3");
  fuzz( 80.6951,  163.5625, "Etc/GMT-11");
  fuzz(-62.6800,   29.5421, "Etc/GMT-2");
  fuzz( 84.8425,   53.0303, "Etc/GMT-4");
  fuzz( 19.6001,  166.6091, "Etc/GMT-11");
  fuzz(-70.9952, -112.0494, "Etc/GMT+7");
  fuzz( 60.9209,  -86.7549, "Etc/GMT+6");
  fuzz(-36.8647,  178.5241, "Etc/GMT-12");
  fuzz(-55.8200, -115.9019, "Etc/GMT+8");
  fuzz( 73.2143,  134.3052, "Etc/GMT-9");
  fuzz( 15.8666,  145.3717, "Etc/GMT-10");
  fuzz( 55.2605,  -14.4721, "Etc/GMT+1");
  fuzz(-36.1862,   96.6795, "Etc/GMT-6");
  fuzz( 34.0615,  149.2062, "Etc/GMT-10");
  fuzz(  4.4731,  145.4425, "Etc/GMT-10");
  fuzz(-39.6374,   93.2593, "Etc/GMT-6");
  fuzz( 73.8246,  125.4436, "Etc/GMT-8");
  fuzz( 84.9775,  -69.1451, "Etc/GMT+5");
  fuzz(-34.9033,  -64.2808, "America/Argentina/Cordoba");
  fuzz( 58.0520,   20.9601, "Etc/GMT-1");
  fuzz( 27.6655,  158.9812, "Etc/GMT-11");
  fuzz(-48.6960, -173.2394, "Etc/GMT+12");
  fuzz(-52.2852, -111.0350, "Etc/GMT+7");
  fuzz(-35.0162, -145.5074, "Etc/GMT+10");
  fuzz( 50.9924, -157.1506, "Etc/GMT+10");
  fuzz(-35.8829,  177.5252, "Etc/GMT-12");
  fuzz(  7.3961,   53.1657, "Etc/GMT-4");
  fuzz(-55.5563,  -76.8690, "Etc/GMT+5");
  fuzz(-58.6263,  -64.1291, "Etc/GMT+4");
  fuzz( 72.6894,   63.4946, "Etc/GMT-4");
  fuzz( 17.3479,  -41.5647, "Etc/GMT+3");
  fuzz(-22.5830, -164.3814, "Etc/GMT+11");
  fuzz(-22.8325,   72.9793, "Etc/GMT-5");
  fuzz(  9.4083, -170.7877, "Etc/GMT+11");
  fuzz(-42.6735,  -53.4609, "Etc/GMT+4");
  fuzz( 11.9140,   -1.7697, "Africa/Ouagadougou");
  fuzz( 81.0019,   -3.2641, "Etc/GMT");
  fuzz( 25.2369,  115.3962, "Asia/Shanghai");
  fuzz( 68.4210,  152.2690, "Asia/Magadan");
  fuzz(-68.9224,  -21.6616, "Etc/GMT+1");
  fuzz(  9.1427, -161.9418, "Etc/GMT+11");
  fuzz(-61.9484,    7.7619, "Etc/GMT-1");
  fuzz(-25.9901,   56.9318, "Etc/GMT-4");
  fuzz( 46.9954,  102.2327, "Asia/Ulaanbaatar");
  fuzz( 66.8532,  136.0681, "Asia/Vladivostok");
  fuzz(-86.7219,  158.4204, "Etc/GMT-11");
  fuzz( 46.4199,  127.2178, "Asia/Harbin");
  fuzz(-81.3502,  -81.1411, "Etc/GMT+5");
  fuzz( 33.5132, -137.8647, "Etc/GMT+9");
  fuzz(  7.5015,   41.0239, "Africa/Addis_Ababa");
  fuzz(-74.2415,  -25.1858, "Etc/GMT+2");
  fuzz(-16.1780,   67.2392, "Etc/GMT-4");
  fuzz( 49.8186,   90.2840, "Asia/Hovd");
  fuzz(-46.7801, -100.5155, "Etc/GMT+7");
  fuzz(  7.1458,   81.9245, "Etc/GMT-5");
  fuzz(-67.3310,  -52.5569, "Etc/GMT+4");
  fuzz(-77.2416,  138.0339, "Etc/GMT-9");
  fuzz( 38.0011, -142.4358, "Etc/GMT+9");
  fuzz( 56.5580, -104.9026, "America/Regina");
  fuzz(  1.3163,  -70.7942, "America/Bogota");
  fuzz(-22.4579,    9.3378, "Etc/GMT-1");
  fuzz(-67.3203, -142.0324, "Etc/GMT+9");
  fuzz( 75.2547,  129.5149, "Etc/GMT-9");
  fuzz( -5.9266,    3.0998, "Etc/GMT");
  fuzz(-15.0202,  127.2482, "Australia/Perth");
  fuzz(-62.8424,  170.2697, "Etc/GMT-11");
  fuzz(-14.8091,   55.5247, "Etc/GMT-4");
  fuzz( 83.5877, -166.1969, "Etc/GMT+11");
  fuzz( 68.0331,  -21.5102, "Etc/GMT+1");
  fuzz(-56.0336,  -99.2588, "Etc/GMT+7");
  fuzz( 86.3244, -121.7303, "Etc/GMT+8");
  fuzz( 11.0656,   61.6343, "Etc/GMT-4");
  fuzz( 28.5442,  158.8094, "Etc/GMT-11");
  fuzz( 41.1258,  141.7440, "Etc/GMT-9");
  fuzz(-82.3286,  166.8406, "Etc/GMT-11");
  fuzz(-61.5605,  113.2465, "Etc/GMT-8");
  fuzz(-62.7417,  -60.1887, "Etc/GMT+4");
  fuzz( 11.6687,  -95.5562, "Etc/GMT+6");
  fuzz( 20.7633,    3.2933, "Africa/Algiers");
  fuzz(-65.4986,  -52.8280, "Etc/GMT+4");
  fuzz( 21.4374, -155.5575, "Etc/GMT+10");
  fuzz(-81.4117, -119.0128, "Etc/GMT+8");
  fuzz(-78.0301, -121.4439, "Etc/GMT+8");
  fuzz(-66.0503, -138.8988, "Etc/GMT+9");
  fuzz( 69.0884,  -61.1057, "Etc/GMT+4");
  fuzz(-77.3035,   39.7992, "Etc/GMT-3");
  fuzz( 13.3045,   66.5813, "Etc/GMT-4");
  fuzz( 55.2926,  146.7279, "Etc/GMT-10");
  fuzz( 58.7958,   56.7150, "Asia/Yekaterinburg");
  fuzz( 57.3421,  -98.0511, "America/Winnipeg");
  fuzz(-13.2898,  -35.6985, "Etc/GMT+2");
  fuzz(-37.7806,  -48.1091, "Etc/GMT+3");
  fuzz(-66.4196,  101.3698, "Etc/GMT-7");
  fuzz(  5.8932, -124.5904, "Etc/GMT+8");
  fuzz(  2.7415,  122.8619, "Etc/GMT-8");
  fuzz(-45.3580,  -91.4156, "Etc/GMT+6");
  fuzz(-79.9406, -120.4636, "Etc/GMT+8");
  fuzz(-67.6450, -169.4275, "Etc/GMT+11");
  fuzz(  3.5563,  -18.2368, "Etc/GMT+1");
  fuzz(  3.6109,  -73.4326, "America/Bogota");
  fuzz(  6.3923,   -6.7531, "Africa/Abidjan");
  fuzz(-67.3733, -111.3979, "Etc/GMT+7");
  fuzz( 75.1526,   81.0746, "Etc/GMT-5");
  fuzz( 87.9364, -174.5277, "Etc/GMT+12");
  fuzz(  6.0728,  112.2950, "Etc/GMT-7");
  fuzz(-87.4797,   32.6313, "Etc/GMT-2");
  fuzz( 27.8449, -151.4113, "Etc/GMT+10");
  fuzz( 31.3301,   60.7153, "Asia/Tehran");
  fuzz( 50.3759,    7.5712, "Europe/Berlin");
  fuzz(  1.7587,   34.0083, "Africa/Kampala");
  fuzz(-26.7159,  149.7563, "Australia/Brisbane");
  fuzz( 87.4481, -132.8037, "Etc/GMT+9");
  fuzz(-49.0685,   22.3684, "Etc/GMT-1");
  fuzz( 13.9236,  -27.7031, "Etc/GMT+2");
  fuzz( 88.2359,  -33.6928, "Etc/GMT+2");
  fuzz( 77.7950,   58.0845, "Etc/GMT-4");
  fuzz(-80.4649,  -48.4704, "Etc/GMT+3");
  fuzz( 45.3066,  -82.0329, "Etc/GMT+5");
  fuzz( 12.4715, -170.8838, "Etc/GMT+11");
  fuzz( 75.1750,  -68.4993, "Etc/GMT+5");
  fuzz( 88.7587, -141.9175, "Etc/GMT+9");
  fuzz(-66.9335, -139.7690, "Etc/GMT+9");
  fuzz(-85.4443,   17.3940, "Etc/GMT-1");
  fuzz(-88.7405,   63.3864, "Etc/GMT-4");
  fuzz(-13.9489,  174.1217, "Etc/GMT-12");
  fuzz(-77.2597,   40.0336, "Etc/GMT-3");
  fuzz(-54.8148,   31.9272, "Etc/GMT-2");
  fuzz(-77.5149,  176.9424, "Etc/GMT-12");
  fuzz(-53.2186,   -5.2936, "Etc/GMT");
  fuzz(-13.1818,  -69.1600, "America/Lima");
  fuzz(-75.7051, -102.7499, "Etc/GMT+7");
  fuzz(  6.3375,  176.2166, "Etc/GMT-12");
  fuzz(-78.3697,  -58.4955, "Etc/GMT+4");
  fuzz(-32.7259,  -52.0219, "Etc/GMT+3");
  fuzz( 75.7244,  163.3695, "Etc/GMT-11");
  fuzz(-35.7110,  122.7878, "Etc/GMT-8");
  fuzz( 23.1049,  -17.9909, "Etc/GMT+1");
  fuzz( 21.3386,  116.9972, "Etc/GMT-8");
  fuzz(-61.6695, -131.8548, "Etc/GMT+9");
  fuzz(-66.8782,  -58.1096, "Etc/GMT+4");
  fuzz(-38.6812, -112.3153, "Etc/GMT+7");
  fuzz( 28.6525,  154.4716, "Etc/GMT-10");
  fuzz( 47.8636,  -64.0314, "Etc/GMT+4");
  fuzz( 44.2626,   44.7455, "Europe/Moscow");
  fuzz( 59.8934, -129.0060, "America/Vancouver");
  fuzz(-44.7503,  116.0809, "Etc/GMT-8");
  fuzz(-76.8437,  170.9782, "Etc/GMT-11");
  fuzz(-15.2087,   -3.7560, "Etc/GMT");
  fuzz( -0.6722,  -77.7137, "America/Guayaquil");
  fuzz(  1.7328, -173.7446, "Etc/GMT+12");
  fuzz( 28.0058,  109.1947, "Asia/Chongqing");
  fuzz(-13.6277,  119.9417, "Etc/GMT-8");
  fuzz( 45.3270, -111.0269, "America/Denver");
  fuzz( 68.3643, -112.3606, "Etc/GMT+7");
  fuzz(-62.9802, -118.6272, "Etc/GMT+8");
  fuzz(-22.9476,   -3.8596, "Etc/GMT");
  fuzz(-53.3245,  -12.7339, "Etc/GMT+1");
  fuzz(-74.1737, -101.2004, "Etc/GMT+7");
  fuzz( -3.9304,  -98.7001, "Etc/GMT+7");
  fuzz(-38.6602,  -57.5274, "Etc/GMT+4");
  fuzz(-21.4916,   18.2277, "Africa/Windhoek");
  fuzz( 69.8075,  -36.7877, "America/Godthab");
  fuzz( 62.4056,   40.1308, "Europe/Moscow");
  fuzz( 28.4828,  -93.3183, "Etc/GMT+6");
  fuzz( 35.6780,  -85.8903, "America/Chicago");
  fuzz( 23.2075,  -47.7451, "Etc/GMT+3");
  fuzz( 11.4899,   88.4851, "Etc/GMT-6");
  fuzz(-44.3420,   94.0902, "Etc/GMT-6");
  fuzz(  4.3710, -149.5973, "Etc/GMT+10");
  fuzz(-34.3776,  -27.6405, "Etc/GMT+2");
  fuzz(-71.7131,  -27.4662, "Etc/GMT+2");
  fuzz(  1.8672,  -65.4309, "America/Caracas");
  fuzz(-11.4081,  -82.5245, "Etc/GMT+6");
  fuzz(-20.3712, -163.5689, "Etc/GMT+11");
  fuzz( 82.3267,  135.9705, "Etc/GMT-9");
  fuzz( -5.2175,  -55.5735, "America/Santarem");
  fuzz(  5.6852,  -21.0037, "Etc/GMT+1");
  fuzz(  7.9257,   83.1164, "Etc/GMT-6");
  fuzz(-27.7641,   73.6055, "Etc/GMT-5");
  fuzz( 83.0263,  147.5772, "Etc/GMT-10");
  fuzz(-67.3774, -125.3727, "Etc/GMT+8");
  fuzz(-65.4147,  136.0511, "Etc/GMT-9");
  fuzz( 11.9703,  -21.7906, "Etc/GMT+1");
  fuzz( 31.1907, -119.8190, "Etc/GMT+8");
  fuzz( 81.8889,  162.7510, "Etc/GMT-11");
  fuzz( 83.4864,  133.1255, "Etc/GMT-9");
  fuzz( 19.3533,   73.4849, "Asia/Kolkata");
  fuzz(  1.1920,   62.6137, "Etc/GMT-4");
  fuzz( 69.7972,  -50.0355, "America/Godthab");
  fuzz( 78.1250,   -5.0552, "Etc/GMT");
  fuzz(-68.6938,  149.2943, "Etc/GMT-10");
  fuzz(-33.2693,  171.4931, "Etc/GMT-11");
  fuzz( 79.2458,  -99.8015, "Etc/GMT+7");
  fuzz( 87.2948, -147.8177, "Etc/GMT+10");
  fuzz(-16.0331,  157.1088, "Etc/GMT-10");
  fuzz(-30.0868,   10.2116, "Etc/GMT-1");
  fuzz(-18.1588,  -38.1290, "Etc/GMT+3");
  fuzz(-56.1562, -101.1797, "Etc/GMT+7");
  fuzz( 37.2952,   90.9628, "Asia/Urumqi");
  fuzz(-34.3471,   58.2842, "Etc/GMT-4");
  fuzz( 14.7315,   20.6226, "Africa/Ndjamena");
  fuzz(-23.6789, -154.9877, "Etc/GMT+10");
  fuzz(-11.9026,   19.1156, "Africa/Luanda");
  fuzz(-19.0649,  -52.4491, "America/Campo_Grande");
  fuzz( 50.5445,  -59.2610, "Etc/GMT+4");
  fuzz( -4.5507,   93.6346, "Etc/GMT-6");
  fuzz(-88.0188,   41.1587, "Etc/GMT-3");
  fuzz( 61.3513, -148.3128, "America/Anchorage");
  fuzz( 73.8546, -120.2774, "America/Yellowknife");
  fuzz(-41.1019, -122.1984, "Etc/GMT+8");
  fuzz(  8.4464, -130.2469, "Etc/GMT+9");
  fuzz( 69.4978,  156.2309, "Asia/Magadan");
  fuzz( 23.2705,   87.0558, "Asia/Kolkata");
  fuzz(  4.0967,   48.8779, "Etc/GMT-3");
  fuzz(  8.1832,  -30.3321, "Etc/GMT+2");
  fuzz( 15.9273,  -92.0672, "America/Mexico_City");
  fuzz( 32.0435,  126.8468, "Etc/GMT-8");
  fuzz( 84.7819,   28.2597, "Etc/GMT-2");
  fuzz( 76.5019,  -72.9037, "Etc/GMT+5");
  fuzz( 67.4221,  -51.8146, "America/Godthab");
  fuzz( 33.8854, -130.1654, "Etc/GMT+9");
  fuzz( 82.9373,  139.8428, "Etc/GMT-9");
  fuzz(-20.2422,  -40.7203, "America/Sao_Paulo");
  fuzz( 59.0311, -126.9869, "America/Vancouver");
  fuzz( -1.4475, -131.7856, "Etc/GMT+9");
  fuzz(-80.8343,   28.9589, "Etc/GMT-2");
  fuzz( 34.4794,  -15.2523, "Etc/GMT+1");
  fuzz(-38.4715,  152.8546, "Etc/GMT-10");
  fuzz( -5.9446,  121.3728, "Etc/GMT-8");
  fuzz( 16.0541, -107.1156, "Etc/GMT+7");
  fuzz( 14.8675,   76.3773, "Asia/Kolkata");
  fuzz( 56.5595,  -85.3237, "Etc/GMT+6");
  fuzz(-67.6002,  135.4160, "Etc/GMT-9");
  fuzz( 75.3114, -177.3905, "Etc/GMT+12");
  fuzz(-26.1632,   16.0042, "Africa/Windhoek");
  fuzz( 65.1068,  -87.7971, "America/Rankin_Inlet");
  fuzz(-41.0747,  -48.6043, "Etc/GMT+3");
  fuzz( 32.1694,  -35.3934, "Etc/GMT+2");
  fuzz(-78.9606,  -29.4712, "Etc/GMT+2");
  fuzz(-70.0754,   50.3924, "Etc/GMT-3");
  fuzz(  4.0183,  154.8668, "Etc/GMT-10");
  fuzz(-22.8129,   93.7666, "Etc/GMT-6");
  fuzz(  6.3683,  -48.1825, "Etc/GMT+3");
  fuzz( 80.8100,  103.8396, "Etc/GMT-7");
  fuzz( -1.2604,   17.7737, "Africa/Kinshasa");
  fuzz(-56.6655,  131.5334, "Etc/GMT-9");
  fuzz( 15.9881,  172.0429, "Etc/GMT-11");
  fuzz( 45.5974,  139.7189, "Etc/GMT-9");
  fuzz(-80.0952,  124.6522, "Etc/GMT-8");
  fuzz( 28.0460, -112.7267, "Etc/GMT+8");
  fuzz(-23.2769,  -77.0398, "Etc/GMT+5");
  fuzz( 22.2298,  136.5771, "Etc/GMT-9");
  fuzz(-53.9516,   54.4962, "Etc/GMT-4");
  fuzz( 26.2379,   12.8011, "Africa/Tripoli");
  fuzz(-38.8550,   24.7027, "Etc/GMT-2");
  fuzz( 33.2165,  114.4249, "Asia/Shanghai");
  fuzz(  7.9894, -155.1491, "Etc/GMT+10");
  fuzz(  2.7781,   96.9558, "Etc/GMT-6");
  fuzz(-48.9592,  142.6809, "Etc/GMT-10");
  fuzz(-87.9616, -173.6335, "Etc/GMT+12");
  fuzz(-43.0451,  -34.4571, "Etc/GMT+2");
  fuzz(-69.1413,  132.6779, "Etc/GMT-9");
  fuzz( -6.6690,  -19.6061, "Etc/GMT+1");
  fuzz(-65.3447,  -30.9381, "Etc/GMT+2");
  fuzz(  3.7725,   21.4347, "Africa/Kinshasa");
  fuzz(  9.1261, -102.8020, "Etc/GMT+7");
  fuzz(  1.5147,  116.9022, "Asia/Makassar");
  fuzz(-66.8727,   63.6803, "Etc/GMT-4");
  fuzz( -8.4033,   97.3167, "Etc/GMT-6");
  fuzz( 74.2024,  124.4017, "Etc/GMT-8");
  fuzz( 74.2058,   18.5639, "Etc/GMT-1");
  fuzz(-75.8910, -161.5193, "Etc/GMT+11");
  fuzz(  8.2735, -135.5986, "Etc/GMT+9");
  fuzz(-74.8124,  -48.9943, "Etc/GMT+3");
  fuzz(-40.5217, -147.1602, "Etc/GMT+10");
  fuzz(-34.4601,  -97.3669, "Etc/GMT+6");
  fuzz( 26.1597,  173.0943, "Etc/GMT-12");
  fuzz(-14.1929,   54.8843, "Etc/GMT-4");
  fuzz( 34.1458,   23.0833, "Etc/GMT-2");
  fuzz( 55.4497,    7.0433, "Etc/GMT");
  fuzz(-78.6307,  113.3832, "Etc/GMT-8");
  fuzz( 21.2209,   54.6444, "Asia/Riyadh");
  fuzz( 70.1277,  164.3757, "Etc/GMT-11");
  fuzz(-58.4174,  110.8558, "Etc/GMT-7");
  fuzz( 21.8934,  130.7189, "Etc/GMT-9");
  fuzz(-24.9981, -137.4371, "Etc/GMT+9");
  fuzz(-32.2273,  -25.8102, "Etc/GMT+2");
  fuzz(-55.1666, -121.5352, "Etc/GMT+8");
  fuzz(-20.1181, -172.9180, "Etc/GMT+12");
  fuzz( 60.5926,  -92.3713, "Etc/GMT+6");
  fuzz( 30.6925,  162.3174, "Etc/GMT-11");
  fuzz(-57.8566,  157.2184, "Etc/GMT-10");
  fuzz(-10.5642,    0.0995, "Etc/GMT");
  fuzz( 33.1621,  125.2617, "Etc/GMT-8");
  fuzz( 55.0640,  -58.5256, "Etc/GMT+4");
  fuzz(-81.3405,  107.4660, "Etc/GMT-7");
  fuzz(-38.4392,  -18.6785, "Etc/GMT+1");
  fuzz(-18.5604,   13.7071, "Africa/Windhoek");
  fuzz(-54.2147,  -82.0964, "Etc/GMT+5");
  fuzz(-69.2399,  167.6421, "Etc/GMT-11");
  fuzz( -9.7067,    1.6729, "Etc/GMT");
  fuzz( 79.6707,   64.3251, "Etc/GMT-4");
  fuzz( 18.5184,  110.4623, "Etc/GMT-7");
  fuzz(-23.7013, -126.2727, "Etc/GMT+8");
  fuzz(-42.0269,   94.6611, "Etc/GMT-6");
  fuzz( 34.7523,  -31.5938, "Etc/GMT+2");
  fuzz(-84.7455,  -69.7055, "Etc/GMT+5");
  fuzz( 73.3086,  -50.3401, "America/Godthab");
  fuzz( 66.0904,  141.2401, "Asia/Magadan");
  fuzz(-58.0650,   25.3396, "Etc/GMT-2");
  fuzz( 17.4341,  -30.0017, "Etc/GMT+2");
  fuzz(-67.3933, -164.0029, "Etc/GMT+11");
  fuzz( 57.5957,   83.7790, "Asia/Novosibirsk");
  fuzz( 62.4294, -160.5397, "America/Anchorage");
  fuzz( 15.6637, -100.0240, "Etc/GMT+7");
  fuzz(-63.6131,   49.2252, "Etc/GMT-3");
  fuzz( 10.0162, -129.1590, "Etc/GMT+9");
  fuzz( 30.4026,  -53.1441, "Etc/GMT+4");
  fuzz( 42.8674,  -27.4990, "Etc/GMT+2");
  fuzz( 34.1233,  163.8765, "Etc/GMT-11");
  fuzz(-50.7374,  113.8433, "Etc/GMT-8");
  fuzz(-57.0372,  168.8475, "Etc/GMT-11");
  fuzz(  5.2829,   35.5583, "Africa/Juba");
  fuzz( 87.3868,   78.4390, "Etc/GMT-5");
  fuzz(-18.9142, -142.6730, "Etc/GMT+10");
  fuzz(-26.0594,   86.4915, "Etc/GMT-6");
  fuzz(-16.7882, -104.7885, "Etc/GMT+7");
  fuzz( 52.1639,  -71.8402, "America/Montreal");
  fuzz(-58.8702,   -3.7338, "Etc/GMT");
  fuzz(-69.0131,  121.7290, "Etc/GMT-8");
  fuzz( 38.9473,   90.3155, "Asia/Urumqi");
  fuzz( 49.7176, -120.6521, "America/Vancouver");
  fuzz(  7.6404, -147.7771, "Etc/GMT+10");
  fuzz( 25.6025,  -99.0005, "America/Monterrey");
  fuzz(-41.2288, -153.4661, "Etc/GMT+10");
  fuzz(-49.9977, -151.5661, "Etc/GMT+10");
  fuzz( 67.5031,  -38.0278, "America/Godthab");
  fuzz( 15.9625,  -45.2139, "Etc/GMT+3");
  fuzz(-46.9936, -104.2446, "Etc/GMT+7");
  fuzz( 13.1211, -138.3129, "Etc/GMT+9");
  fuzz( 42.6345,   95.3104, "Asia/Urumqi");
  fuzz(-15.8933, -104.0792, "Etc/GMT+7");
  fuzz(-52.0663, -108.8869, "Etc/GMT+7");
  fuzz(-88.8353,   65.5915, "Etc/GMT-4");
  fuzz(-65.8830,   52.1290, "Etc/GMT-3");
  fuzz( 83.5015, -113.9396, "Etc/GMT+8");
  fuzz(-72.3536,  -37.8608, "Etc/GMT+3");
  fuzz( 43.4929,   78.0778, "Asia/Almaty");
  fuzz( 58.7754, -120.0701, "America/Vancouver");
  fuzz(-83.3062,   29.2595, "Etc/GMT-2");
  fuzz(  8.0682, -144.6451, "Etc/GMT+10");
  fuzz(-55.2859,    5.3289, "Etc/GMT");
  fuzz(-82.2308, -150.1518, "Etc/GMT+10");
  fuzz(-76.2477,   63.5011, "Etc/GMT-4");
  fuzz(  0.1582,  -77.8423, "America/Guayaquil");
  fuzz( 60.8634, -131.1674, "America/Whitehorse");
  fuzz( 23.7231,  142.9356, "Etc/GMT-10");
  fuzz( 33.0686,  -67.5551, "Etc/GMT+5");
  fuzz( 84.3853,  158.8676, "Etc/GMT-11");
  fuzz( 14.9421,  143.7985, "Etc/GMT-10");
  fuzz( 78.6392,   -1.8328, "Etc/GMT");
  fuzz(-25.9674,  -33.9196, "Etc/GMT+2");
  fuzz( -2.3241,  -65.9156, "America/Manaus");
  fuzz( 82.3387,  117.3817, "Etc/GMT-8");
  fuzz( 78.8354, -153.4039, "Etc/GMT+10");
  fuzz(-23.8073,  160.3795, "Etc/GMT-11");
  fuzz( 22.9561,  169.7119, "Etc/GMT-11");
  fuzz( 25.8736,  174.0861, "Etc/GMT-12");
  fuzz( 50.7440,  -19.2759, "Etc/GMT+1");
  fuzz( 51.2849,   31.5151, "Europe/Kiev");
  fuzz(-31.7684,  179.1111, "Etc/GMT-12");
  fuzz( 88.1240,  138.5029, "Etc/GMT-9");
  fuzz( -3.6522,   84.8058, "Etc/GMT-6");
  fuzz( -0.6626,   17.8965, "Africa/Kinshasa");
  fuzz( 73.2245,  -96.8935, "America/Rankin_Inlet");
  fuzz(-65.6293, -162.2939, "Etc/GMT+11");
  fuzz( -6.2707, -114.7398, "Etc/GMT+8");
  fuzz( 32.3177,   46.9431, "Asia/Baghdad");
  fuzz( 74.0594, -161.8340, "Etc/GMT+11");
  fuzz(-53.0567,   -6.2848, "Etc/GMT");
  fuzz(-26.5587, -166.8372, "Etc/GMT+11");
  fuzz(-33.0114,  -83.9625, "Etc/GMT+6");
  fuzz( 84.6573, -120.7351, "Etc/GMT+8");
  fuzz( 42.9075, -127.0473, "Etc/GMT+8");
  fuzz( 66.4740,   -7.6684, "Etc/GMT+1");
  fuzz( 13.7236,  155.8073, "Etc/GMT-10");
  fuzz( 26.5912, -160.2199, "Etc/GMT+11");
  fuzz( -9.5098, -118.9338, "Etc/GMT+8");
  fuzz( 42.7964, -117.8366, "America/Boise");
  fuzz(-53.2370, -110.3438, "Etc/GMT+7");
  fuzz(-46.5066,   -5.7933, "Etc/GMT");
  fuzz( 43.5323,   65.9852, "Asia/Qyzylorda");
  fuzz(-14.8929,  176.7410, "Etc/GMT-12");
  fuzz( 74.4332,  146.5022, "Etc/GMT-10");
  fuzz(-88.7197,  -74.5801, "Etc/GMT+5");
  fuzz(-81.6059,  -66.0499, "Etc/GMT+4");
  fuzz( 82.8924,  117.1657, "Etc/GMT-8");
  fuzz( 42.1978, -162.8859, "Etc/GMT+11");
  fuzz( 68.5219, -120.2687, "America/Cambridge_Bay");
  fuzz(-69.5101, -159.3780, "Etc/GMT+11");
  fuzz( -0.5889,   69.6335, "Etc/GMT-5");
  fuzz(-20.3995, -126.8338, "Etc/GMT+8");
  fuzz(-27.4319,   -3.3868, "Etc/GMT");
  fuzz(-30.1655,  -27.1847, "Etc/GMT+2");
  fuzz( 21.9848,  -79.4824, "America/Havana");
  fuzz(-10.6270,  -23.2325, "Etc/GMT+2");
  fuzz(-65.1066,   45.3748, "Etc/GMT-3");
  fuzz( 19.1666,  -65.2812, "Etc/GMT+4");
  fuzz(  3.1742,   29.6364, "Africa/Lubumbashi");
  fuzz(-41.6524,   77.7600, "Etc/GMT-5");
  fuzz( 45.4705,  135.6598, "Asia/Vladivostok");
  fuzz( -2.8117, -148.7114, "Etc/GMT+10");
  fuzz( 52.9221,  101.7918, "Asia/Irkutsk");
  fuzz( 59.9514,  -21.5620, "Etc/GMT+1");
  fuzz( 35.9786,   18.6561, "Etc/GMT-1");
  fuzz(-80.4222,   72.2841, "Etc/GMT-5");
  fuzz( 13.9315,  -91.7841, "Etc/GMT+6");
  fuzz( 14.7296,  149.1903, "Etc/GMT-10");
  fuzz(-85.1898, -144.2367, "Etc/GMT+10");
  fuzz( 18.1641,   18.4528, "Africa/Ndjamena");
  fuzz(  8.6146,  -65.2355, "America/Caracas");
  fuzz( 37.3193,  102.0327, "Asia/Chongqing");
  fuzz( 73.6035,   18.9112, "Etc/GMT-1");
  fuzz(-36.2548,   67.0493, "Etc/GMT-4");
  fuzz(-78.3310, -158.2771, "Etc/GMT+11");
  fuzz( 45.9851,  -64.3935, "America/Moncton");
  fuzz(-19.4491,   96.8690, "Etc/GMT-6");
  fuzz(-23.4809,  -30.3441, "Etc/GMT+2");
  fuzz( -6.6831,   22.1025, "Africa/Lubumbashi");
  fuzz( 64.1049,   89.7467, "Asia/Krasnoyarsk");
  fuzz(-49.7391,  108.5411, "Etc/GMT-7");
  fuzz(-66.1253, -141.0435, "Etc/GMT+9");
  fuzz(-10.1499,   57.9375, "Etc/GMT-4");
  fuzz(-28.1880,  119.3906, "Australia/Perth");
  fuzz(-45.3193,  157.2543, "Etc/GMT-10");
  fuzz(-47.5170,   89.7839, "Etc/GMT-6");
  fuzz(-39.2064,   83.4890, "Etc/GMT-6");
  fuzz(-23.5594,  142.2289, "Australia/Brisbane");
  fuzz( 22.0641,  -61.0754, "Etc/GMT+4");
  fuzz( 22.4934,  -12.2664, "Africa/Nouakchott");
  fuzz(-42.2724,   54.5976, "Etc/GMT-4");
  fuzz(-45.7927,  157.8576, "Etc/GMT-11");
  fuzz(-59.2510, -170.8427, "Etc/GMT+11");
  fuzz( 17.1192,  -12.8761, "Africa/Nouakchott");
  fuzz( 51.4541,   43.3003, "Europe/Volgograd");
  fuzz(-78.0191,   51.2241, "Etc/GMT-3");
  fuzz( 15.1609,   76.2168, "Asia/Kolkata");
  fuzz( 60.0202,   89.4423, "Asia/Krasnoyarsk");
  fuzz( 19.7517,  114.3184, "Etc/GMT-8");
  fuzz( 41.8693,   -5.9326, "Europe/Madrid");
  fuzz(-50.7551, -141.3429, "Etc/GMT+9");
  fuzz(-71.2020,   56.1700, "Etc/GMT-4");
  fuzz( 89.6557,  -33.2015, "Etc/GMT+2");
  fuzz(  4.2187,  -62.7399, "America/Caracas");
  fuzz( 69.5304,   85.2865, "Asia/Krasnoyarsk");
  fuzz( -2.2434,   66.3365, "Etc/GMT-4");
  fuzz( 67.4545,  -15.5863, "Etc/GMT+1");
  fuzz( 36.6934,  113.5059, "Asia/Shanghai");
  fuzz(-50.7986, -158.6501, "Etc/GMT+11");
  fuzz(-41.6788,   35.8979, "Etc/GMT-2");
  fuzz( 17.4480,   49.6467, "Asia/Aden");
  fuzz( 46.8508,  -75.1992, "America/Montreal");
  fuzz( 67.2406, -168.2671, "Etc/GMT+11");
  fuzz( 77.6446,    2.3212, "Etc/GMT");
  fuzz(-61.9257,   91.2970, "Etc/GMT-6");
  fuzz( 71.4531,  -46.1878, "America/Godthab");
  fuzz(-37.4798,  168.5746, "Etc/GMT-11");
  fuzz(-66.1172, -107.3644, "Etc/GMT+7");
  fuzz(-23.8911,   -0.2210, "Etc/GMT");
  fuzz(  1.1704,  169.2886, "Etc/GMT-11");
  fuzz(-15.5359,  -28.0257, "Etc/GMT+2");
  fuzz( 37.9974, -157.9686, "Etc/GMT+11");
  fuzz( 84.1284,   24.9015, "Etc/GMT-2");
  fuzz( 58.6358, -178.3768, "Etc/GMT+12");
  fuzz( 19.3079,  -66.2011, "Etc/GMT+4");
  fuzz( 72.6499, -142.3623, "Etc/GMT+9");
  fuzz( 45.1464,  -64.2392, "Etc/GMT+4");
  fuzz(-22.6969,   82.0516, "Etc/GMT-5");
  fuzz( 14.5328,   20.0108, "Africa/Ndjamena");
  fuzz( 83.3319,  152.6302, "Etc/GMT-10");
  fuzz(-89.7084,  -66.8879, "Etc/GMT+4");
  fuzz(-76.2955,   26.3697, "Etc/GMT-2");
  fuzz( 39.5678,  155.9731, "Etc/GMT-10");
  fuzz(-34.2466,   28.2191, "Etc/GMT-2");
  fuzz( 23.5053, -133.4521, "Etc/GMT+9");
  fuzz( 49.0779,  105.2610, "Asia/Ulaanbaatar");
  fuzz( 23.1338,  136.8832, "Etc/GMT-9");
  fuzz(-69.5296,    8.6637, "Etc/GMT-1");
  fuzz(-10.7260,  -66.9046, "America/La_Paz");
  fuzz(-52.9070,  -64.3141, "Etc/GMT+4");
  fuzz(-75.2765,   12.9668, "Etc/GMT-1");
  fuzz(-84.9268,  111.2002, "Etc/GMT-7");
  fuzz(  2.8088,    5.8149, "Etc/GMT");
  fuzz( 27.9470, -159.7298, "Etc/GMT+11");
  fuzz( 31.2644,   21.7824, "Africa/Tripoli");
  fuzz(-33.7152,   57.4777, "Etc/GMT-4");
  fuzz(-72.8925,    8.1550, "Etc/GMT-1");
  fuzz( 86.3789,  -92.7214, "Etc/GMT+6");
  fuzz( -2.8395,  -82.7568, "Etc/GMT+6");
  fuzz( -6.2681,  162.6282, "Etc/GMT-11");
  fuzz(  0.4849,   90.5215, "Etc/GMT-6");
  fuzz(-34.9507,  106.0544, "Etc/GMT-7");
  fuzz(-78.7634,   86.7459, "Etc/GMT-6");
  fuzz(  0.0154,   84.8139, "Etc/GMT-6");
  fuzz( 57.2329,   94.6034, "Asia/Krasnoyarsk");
  fuzz( 12.6608,  -87.2430, "America/Managua");
  fuzz( 63.4155, -109.7556, "America/Yellowknife");
  fuzz( -4.3070,    8.2002, "Etc/GMT-1");
  fuzz(-35.1741,   51.2478, "Etc/GMT-3");
  fuzz( 41.8814, -113.9326, "America/Denver");
  fuzz( 41.5321,  129.6820, "Etc/GMT-9");
  fuzz(-28.8000, -159.6561, "Etc/GMT+11");
  fuzz(-25.6553,   -9.6209, "Etc/GMT+1");
  fuzz(-78.4740,  -10.7556, "Etc/GMT+1");
  fuzz(-76.9039, -152.6478, "Etc/GMT+10");
  fuzz(-87.5954,  -33.2032, "Etc/GMT+2");
  fuzz( 32.1715,  -65.5929, "Etc/GMT+4");
  fuzz( 86.5482,  171.5572, "Etc/GMT-11");
  fuzz(-55.7154,  -81.3795, "Etc/GMT+5");
  fuzz(-71.9363, -177.4033, "Etc/GMT+12");
  fuzz( 26.7034,  176.4187, "Etc/GMT-12");
  fuzz(  8.1392,   80.1801, "Asia/Colombo");
  fuzz( 78.8040,  132.7289, "Etc/GMT-9");
  fuzz(-84.4793,  165.8169, "Etc/GMT-11");
  fuzz( 53.9195,  107.1539, "Asia/Irkutsk");
  fuzz( 89.9736,  -27.3367, "Etc/GMT+2");
  fuzz( 29.5765,   28.8024, "Africa/Cairo");
  fuzz( 28.6111,  -87.0524, "Etc/GMT+6");
  fuzz(-38.1483, -171.9267, "Etc/GMT+11");
  fuzz( 34.1592,   95.6204, "Asia/Urumqi");
  fuzz( 75.7569,  -40.2910, "America/Godthab");
  fuzz(-59.9774,   39.9417, "Etc/GMT-3");
  fuzz(-37.3039,  161.3992, "Etc/GMT-11");
  fuzz( 54.6688, -115.0705, "America/Edmonton");
  fuzz(-62.5436,  137.8440, "Etc/GMT-9");
  fuzz( -8.8954,  -38.3336, "America/Recife");
  fuzz( 67.2404,   94.0746, "Asia/Krasnoyarsk");
  fuzz( 18.2167,  159.4189, "Etc/GMT-11");
  fuzz( 73.9764,   56.1288, "Europe/Moscow");
  fuzz(-59.8771,    7.1490, "Etc/GMT");
  fuzz(  1.3357,  157.1211, "Etc/GMT-10");
  fuzz(-31.6969,   80.6164, "Etc/GMT-5");
  fuzz( 58.4602,   25.1753, "Europe/Tallinn");
  fuzz( 24.9978,  -53.9309, "Etc/GMT+4");
  fuzz(-66.0219,  171.5308, "Etc/GMT-11");
  fuzz(-72.4044, -109.6574, "Etc/GMT+7");
  fuzz( 83.8181, -107.9618, "Etc/GMT+7");
  fuzz( -0.3325,  121.2628, "Etc/GMT-8");
  fuzz(-10.4374, -137.4015, "Etc/GMT+9");
  fuzz( 71.9566, -135.0044, "Etc/GMT+9");
  fuzz( 28.7239,   27.2395, "Africa/Cairo");
  fuzz( 15.9964,  149.5303, "Etc/GMT-10");
  fuzz( 75.2983,   99.6727, "Asia/Krasnoyarsk");
});
